@@ -1,16 +1,13 @@
 import logging
-from enum import Enum, IntEnum
+from enum import IntEnum
 from inspect import cleandoc
-from typing import Any, Dict, List, Optional, Tuple, Type, Union
 
-from pydantic.types import PositiveInt, confloat, conint, constr
+from pydantic import Field, StringConstraints
+from pydantic.types import PositiveInt
+from typing_extensions import Annotated
 
 from geolib.models import BaseDataClass
-from geolib.models.base_model_structure import BaseModelStructure
 from geolib.models.dseries_parser import (
-    DSerieListStructure,
-    DSerieMatrixStructure,
-    DSerieOldTableStructure,
     DSeriesInlineMappedProperties,
     DSeriesInlineProperties,
     DSeriesNoParseSubStructure,
@@ -39,37 +36,40 @@ REQ_RUN_LINES = 6
 
 
 class PileType(IntEnum):
-    PREFABRICATED_CONCRETE_PILE = 0
-    CLOSED_ENDED_STEEL_PIPE_PILE = 1
-    DRIVEN_CAST_IN_PLACE_PILE_TUBE_BACK_BY_DRIVING = 2
-    DRIVEN_CAST_IN_PLACE_PILE_TUBE_BACK_BY_VIBRATION = 3
-    TAPERED_TIMBER_PILE = 4
-    STRAIGHT_TIMBER_PILE = 5
-    SCREW_PILE_CAST_IN_PLACE_LOST_TIP = 6
-    SCREW_PILE_CAST_IN_PLACE_WITH_GROUT = 7
-    PREFABRICATED_SCREW_PILE_WITH_GROUT = 8
-    PREFABRICATED_SCREW_PILE_WITHOUT_GROUT = 9
-    STEEL_SECTION = 10
-    CONTINUOUS_FLIGHT_AUGER_PILE = 11
-    BORED_PILE_DRILLING_MUD_UNCASED_BOREHOLE = 12
-    BORED_PILE_SHELLING_TECH_PERMANENT_CASING = 13
-    OPEN_ENDED_STEEL_PIPE_PILE = 14
-    MV_PILE = 15
-    MICRO_PILE_DOUBLE_PIPE_EXTORTED = 16
-    MICRO_PILE_DOUBLE_PIPE_NOT_EXTORTED = 17
-    MICRO_PILE_SINGLE_PIPE_EXTORTED = 18
-    MICRO_PILE_SINGLE_PIPE_NOT_EXTORTED = 19
-    MICRO_PILE_ANCHOR_BORED = 20
-    MICRO_PILE_ANCHOR_SCREWED = 21
-    MICRO_PILE_VIBRATED = 22
-    GROUTED_STEEL_PROFILE_WITH_FOOTPLATE = 23
-    GROUTED_STEEL_PIPE_PILE_SCREWED = 24
-    USER_DEFINED_VIBRATING = 25
-    USER_DEFINED_LOW_VIBRATING = 26
-    USER_DEFINED = 27
+    B1_PREFABRICATED_CONCRETE_PILE = 0
+    S1_CLOSED_ENDED_STEEL_PIPE_PILE = 1
+    B2_DRIVEN_CAST_IN_PLACE_PILE_TUBE_BACK_BY_DRIVING = 2
+    B3_DRIVEN_CAST_IN_PLACE_PILE_TUBE_BACK_BY_VIBRATION = 3
+    H2_TAPERED_TIMBER_PILE = 4
+    H1_STRAIGHT_TIMBER_PILE = 5
+    B4_SCREW_PILE_CAST_IN_PLACE_LOST_TIP = 6
+    B4_SCREW_PILE_CAST_IN_PLACE_WITH_GROUT = 7
+    Old_PREFABRICATED_SCREW_PILE_WITH_GROUT = 8
+    S5_PREFABRICATED_SCREW_PILE_WITHOUT_GROUT = 9
+    S2_STEEL_SECTION = 10
+    B7_CONTINUOUS_FLIGHT_AUGER_PILE = 11
+    B8_BORED_PILE_DRILLING_MUD_UNCASED_BOREHOLE = 12
+    S7_BORED_PILE_SHELLING_TECH_PERMANENT_CASING = 13
+    S3_OPEN_ENDED_STEEL_PIPE_PILE = 14
+    S4_MV_PILE = 15
+    MA2_MICRO_PILE_DOUBLE_PIPE_EXTORTED = 16
+    MA1_MICRO_PILE_DOUBLE_PIPE_NOT_EXTORTED = 17
+    MB2_MICRO_PILE_SINGLE_PIPE_EXTORTED = 18
+    MB1_MICRO_PILE_SINGLE_PIPE_NOT_EXTORTED = 19
+    MC_MICRO_PILE_ANCHOR_BORED = 20
+    MD_MICRO_PILE_ANCHOR_SCREWED = 21
+    ME_MICRO_PILE_VIBRATED = 22
+    S4_GROUTED_STEEL_PROFILE_WITH_FOOTPLATE = 23
+    S6_GROUTED_STEEL_PIPE_PILE_SCREWED = 24
+    B5_SCREW_PILE_WITH_AUGER = 25
+    B6_ROUND_SCREW_PILE_WITH_GROUT = 26
+    MF_ANY_OTHER_MICRO_PILE = 27
+    USER_DEFINED_VIBRATING = 28
+    USER_DEFINED_LOW_VIBRATING = 29
+    USER_DEFINED = 30
 
 
-class PileTypeForClayLoamPeat(IntEnum):
+class PileTypeForClaySiltPeat(IntEnum):
     STANDARD = 0
     USER_DEFINED = 1
 
@@ -87,6 +87,14 @@ class PileMaterial(IntEnum):
     USER_DEFINED = 3
 
 
+class InstallationMethod(IntEnum):
+    AUTOMATIC = 0
+    DRIVING = 1
+    VIBRATING = 2
+    PRESSING = 3
+    JETTING = 4
+
+
 class BearingPileSlipLayer(IntEnum):
     NONE = 0
     SYNTHETIC = 1
@@ -94,6 +102,9 @@ class BearingPileSlipLayer(IntEnum):
     BITUMEN = 3
     USER_DEFINED = 4
 
+class OpenPipePileCalculationMethod(IntEnum):
+    OPEN_PIPE_PILE = 0
+    STANDARD_METHOD = 1
 
 class PileShape(IntEnum):
     ROUND_PILE = 0
@@ -108,86 +119,92 @@ class PileShape(IntEnum):
     ROUND_OPEN_ENDED_HOLLOW_PILE = 9
     H_SHAPED_PROFILE = 10
     USER_DEFINED = 11
+    ROUND_PILE_WITH_SCREW_SHAPED_SHAFT = 12
+    ROUND_PILE_WITH_BASE_EQUALS_TO_SHAFT_LOST_TIP = 13
 
 
 class TypesBearingPiles(DSeriesNoParseSubStructure):
     pile_name: str = ""
-    pile_type: PileType = PileType.PREFABRICATED_CONCRETE_PILE
-    pile_type_for_execution_factor_sand_gravel: Optional[PileType]
-    execution_factor_sand_gravel: Optional[confloat(ge=0, le=9)]
-    pile_type_for_execution_factor_clay_loam_peat: Optional[PileTypeForClayLoamPeat]
-    execution_factor_clay_loam_peat: Optional[confloat(ge=0, le=9)]
-    pile_type_for_pile_class_factor: Optional[PileType]
-    pile_class_factor: Optional[confloat(ge=0, le=9)]
-    pile_type_for_load_settlement_curve: Optional[LoadSettlementCurve]
-    material: Optional[PileMaterial]
-    elasticity_modulus: Optional[confloat(ge=0, le=1e25)]
+    pile_type: PileType = PileType.B1_PREFABRICATED_CONCRETE_PILE
+    pile_type_for_execution_factor_sand_gravel: PileType | None = None
+    execution_factor_sand_gravel: Annotated[float, Field(ge=0, le=9)] | None = None
+    pile_type_for_execution_factor_clay_silt_peat: PileTypeForClaySiltPeat | None = None
+    execution_factor_clay_silt_peat: Annotated[float, Field(ge=0, le=9)] | None = None
+    pile_type_for_pile_class_factor: PileType | None = None
+    pile_class_factor: Annotated[float, Field(ge=0, le=9)] | None = None
+    pile_type_for_load_settlement_curve: LoadSettlementCurve | None = None
+    material: PileMaterial | None = None
+    elasticity_modulus: Annotated[float, Field(ge=0, le=1e25)] | None = None
+    installation_method: InstallationMethod = InstallationMethod.DRIVING
     slip_layer: BearingPileSlipLayer = BearingPileSlipLayer.NONE
-    characteristic_adhesion: Optional[confloat(ge=0, le=1000)]
+    characteristic_adhesion: Annotated[float, Field(ge=0, le=1000)] | None = None
     shape: PileShape = PileShape.RECTANGULAR_PILE
-    base_width: Optional[confloat(ge=0, le=100)]
-    base_length: Optional[confloat(ge=0, le=100)]
-    diameter: Optional[confloat(ge=0, le=100)]
-    base_diameter: Optional[confloat(ge=0, le=100)]
-    pile_diameter: Optional[confloat(ge=0, le=100)]
-    base_height: Optional[confloat(ge=0, le=100)]
-    base_width_v: Optional[confloat(ge=0, le=100)]
-    base_length_v: Optional[confloat(ge=0, le=100)]
-    shaft_width: Optional[confloat(ge=0, le=100)]
-    shaft_length: Optional[confloat(ge=0, le=100)]
-    increase_in_diameter: Optional[confloat(ge=0, le=100)]
-    external_diameter: Optional[confloat(ge=0, le=100)]
-    internal_diameter: Optional[confloat(ge=0, le=100)]
-    height_h_shape: Optional[confloat(ge=0, le=100)]
-    width_h_shape: Optional[confloat(ge=0, le=100)]
-    thickness_web: Optional[confloat(ge=0, le=100)]
-    thickness_flange: Optional[confloat(ge=0, le=100)]
+    base_width: Annotated[float, Field(ge=0, le=100)] | None = None
+    base_length: Annotated[float, Field(ge=0, le=100)] | None = None
+    diameter: Annotated[float, Field(ge=0, le=100)] | None = None
+    base_diameter: Annotated[float, Field(ge=0, le=100)] | None = None
+    pile_diameter: Annotated[float, Field(ge=0, le=100)] | None = None
+    base_height: Annotated[float, Field(ge=0, le=100)] | None = None
+    base_width_v: Annotated[float, Field(ge=0, le=100)] | None = None
+    base_length_v: Annotated[float, Field(ge=0, le=100)] | None = None
+    shaft_width: Annotated[float, Field(ge=0, le=100)] | None = None
+    shaft_length: Annotated[float, Field(ge=0, le=100)] | None = None
+    increase_in_diameter: Annotated[float, Field(ge=0, le=100)] | None = None
+    external_diameter: Annotated[float, Field(ge=0, le=100)] | None = None
+    internal_diameter: Annotated[float, Field(ge=0, le=100)] | None = None
+    height_h_shape: Annotated[float, Field(ge=0, le=100)] | None = None
+    width_h_shape: Annotated[float, Field(ge=0, le=100)] | None = None
+    thickness_web: Annotated[float, Field(ge=0, le=100)] | None = None
+    thickness_flange: Annotated[float, Field(ge=0, le=100)] | None = None
+    open_pipe_pile_calculation_method: OpenPipePileCalculationMethod = OpenPipePileCalculationMethod.OPEN_PIPE_PILE
     overrule_pile_tip_shape_factor: Bool = Bool.FALSE
-    pile_tip_shape_factor: Optional[confloat(ge=0, le=10)]
+    pile_tip_shape_factor: Annotated[float, Field(ge=0, le=10)] | None = None
     overrule_pile_tip_cross_section_factors: Bool = Bool.FALSE
-    pile_tip_cross_section_factor: Optional[confloat(ge=0, le=10)]
-    use_pre_2016: Bool = Bool.FALSE
+    pile_tip_cross_section_factor: Annotated[float, Field(ge=0, le=10)] | None = None
+    use_pre_2025: Bool = Bool.FALSE
     user_defined_pile_type_as_prefab: Bool = Bool.FALSE
     use_manual_reduction_for_qc: Bool = Bool.FALSE
-    reduction_percentage_qc: confloat(ge=25, le=100) = 25
+    reduction_percentage_qc: Annotated[float, Field(ge=25, le=100)] = 25
     is_user_defined: Bool = Bool.TRUE
 
 
 class TypesTensionPiles(DSeriesNoParseSubStructure):
     pile_name: str = ""
-    pile_type: PileType = PileType.PREFABRICATED_CONCRETE_PILE
-    pile_type_for_execution_factor_sand_gravel: Optional[PileType]
-    execution_factor_sand_gravel: Optional[confloat(ge=0, le=9)]
-    pile_type_for_execution_factor_clay_loam_peat: Optional[PileTypeForClayLoamPeat]
-    execution_factor_clay_loam_peat: Optional[confloat(ge=0, le=9)]
-    material: Optional[PileMaterial]
-    unit_weight_pile: Optional[confloat(ge=0, le=1000)]
-    elasticity_modulus: Optional[confloat(ge=0, le=1e25)]
+    pile_type: PileType = PileType.B1_PREFABRICATED_CONCRETE_PILE
+    pile_type_for_execution_factor_sand_gravel: PileType | None = None
+    use_pre_2025: Bool = Bool.FALSE
+    installation_method: InstallationMethod = InstallationMethod.DRIVING
+    execution_factor_sand_gravel: Annotated[float, Field(ge=0, le=9)] | None = None
+    pile_type_for_execution_factor_clay_silt_peat: PileTypeForClaySiltPeat | None = None
+    execution_factor_clay_silt_peat: Annotated[float, Field(ge=0, le=9)] | None = None
+    material: PileMaterial | None = None
+    unit_weight_pile: Annotated[float, Field(ge=0, le=1000)] | None = None
+    elasticity_modulus: Annotated[float, Field(ge=0, le=1e25)] | None = None
     shape: PileShape = PileShape.RECTANGULAR_PILE
-    base_width: Optional[confloat(ge=0, le=100)]
-    base_length: Optional[confloat(ge=0, le=100)]
-    diameter: Optional[confloat(ge=0, le=100)]
-    base_diameter: Optional[confloat(ge=0, le=100)]
-    pile_diameter: Optional[confloat(ge=0, le=100)]
-    base_height: Optional[confloat(ge=0, le=100)]
-    base_width_v: Optional[confloat(ge=0, le=100)]
-    base_length_v: Optional[confloat(ge=0, le=100)]
-    shaft_width: Optional[confloat(ge=0, le=100)]
-    shaft_length: Optional[confloat(ge=0, le=100)]
-    increase_in_diameter: Optional[confloat(ge=0, le=100)]
-    external_diameter: Optional[confloat(ge=0, le=100)]
-    internal_diameter: Optional[confloat(ge=0, le=100)]
-    height_h_shape: Optional[confloat(ge=0, le=100)]
-    width_h_shape: Optional[confloat(ge=0, le=100)]
-    thickness_web: Optional[confloat(ge=0, le=100)]
-    thickness_flange: Optional[confloat(ge=0, le=100)]
-    circumference: Optional[confloat(ge=0, le=100)]
-    cross_section: Optional[confloat(ge=0, le=100)]
+    base_width: Annotated[float, Field(ge=0, le=100)] | None = None
+    base_length: Annotated[float, Field(ge=0, le=100)] | None = None
+    diameter: Annotated[float, Field(ge=0, le=100)] | None = None
+    base_diameter: Annotated[float, Field(ge=0, le=100)] | None = None
+    pile_diameter: Annotated[float, Field(ge=0, le=100)] | None = None
+    base_height: Annotated[float, Field(ge=0, le=100)] | None = None
+    base_width_v: Annotated[float, Field(ge=0, le=100)] | None = None
+    base_length_v: Annotated[float, Field(ge=0, le=100)] | None = None
+    shaft_width: Annotated[float, Field(ge=0, le=100)] | None = None
+    shaft_length: Annotated[float, Field(ge=0, le=100)] | None = None
+    increase_in_diameter: Annotated[float, Field(ge=0, le=100)] | None = None
+    external_diameter: Annotated[float, Field(ge=0, le=100)] | None = None
+    internal_diameter: Annotated[float, Field(ge=0, le=100)] | None = None
+    height_h_shape: Annotated[float, Field(ge=0, le=100)] | None = None
+    width_h_shape: Annotated[float, Field(ge=0, le=100)] | None = None
+    thickness_web: Annotated[float, Field(ge=0, le=100)] | None = None
+    thickness_flange: Annotated[float, Field(ge=0, le=100)] | None = None
+    circumference: Annotated[float, Field(ge=0, le=100)] | None = None
+    cross_section: Annotated[float, Field(ge=0, le=100)] | None = None
     is_user_defined: Bool = Bool.TRUE
 
 
 class SoilCollection(DSeriesStructureCollection):
-    soil: List[Soil] = Soil.default_soils()
+    soil: list[Soil] = Soil.default_soils()
 
     def add_soil_if_unique(self, soil) -> None:
         for added_soil in self.soil:
@@ -219,10 +236,10 @@ class Layer(DSeriesTreeStructure):
     excess_pore_pressure_top: float = 0.0  # [kN/m3]
     excess_pore_pressure_bottom: float = 0.0  # [kN/m3]
     ocr_value: float = 1.0  # [-]
-    reduction_core_resistance: int = 0  # [%]
+    reduction_cone_resistance: float = 0.0  # [%]
 
 
-class ReductionCoreResistanceEnum(IntEnum):
+class ReductionConeResistanceEnum(IntEnum):
     SAFE = 0
     BEGEMANN = 1
     MANUAL = 2
@@ -244,19 +261,19 @@ class Profile(DSeriesTreeStructure):
     top_tension_zone: float = 0.0
 
     # Excavation part
-    reduction_of_core_resistance: ReductionCoreResistanceEnum = (
-        ReductionCoreResistanceEnum.SAFE
+    reduction_of_cone_resistance: ReductionConeResistanceEnum = (
+        ReductionConeResistanceEnum.SAFE
     )
     excavation_level: float
     excavation_width_infinite: Bool = Bool.TRUE
     excavation_length_infinite: Bool = Bool.TRUE
     distance_edge_pile_to_excavation_boundary: float = 0.0  # only valid for BEGEMANN
 
-    layers: List[Layer] = []
+    layers: list[Layer] = []
 
 
 class Profiles(DSeriesTreeStructureCollection):
-    profiles: List[Profile] = []
+    profiles: list[Profile] = []
 
     def add_profile_if_unique(self, profile: Profile) -> Profile:
         for added_profile in self.profiles:
@@ -285,38 +302,38 @@ class InternalPile(BaseDataClass):
 
 class PositionBearingPile(InternalPile):
     index: PositiveInt = 1
-    x_coordinate: confloat(ge=-10000000, le=100000000)
-    y_coordinate: confloat(ge=-10000000, le=100000000)
-    pile_head_level: confloat(ge=-1000, le=1000)
-    surcharge: confloat(ge=0, le=100000)
-    limit_state_str: confloat(ge=0, le=100000)
-    limit_state_service: confloat(ge=0, le=100000)
-    pile_name: constr(min_length=1, max_length=10)
+    x_coordinate: Annotated[float, Field(ge=-10000000, le=100000000)]
+    y_coordinate: Annotated[float, Field(ge=-10000000, le=100000000)]
+    pile_head_level: Annotated[float, Field(ge=-1000, le=1000)]
+    surcharge: Annotated[float, Field(ge=0, le=100000)]
+    limit_state_str: Annotated[float, Field(ge=0, le=100000)]
+    limit_state_service: Annotated[float, Field(ge=0, le=100000)]
+    pile_name: Annotated[str, StringConstraints(min_length=1, max_length=100)]
 
 
 class PositionTensionPile(InternalPile):
     index: PositiveInt = 1
-    x_coordinate: confloat(ge=-10000000, le=100000000)
-    y_coordinate: confloat(ge=-10000000, le=100000000)
-    pile_head_level: confloat(ge=-1000, le=1000)
+    x_coordinate: Annotated[float, Field(ge=-10000000, le=100000000)]
+    y_coordinate: Annotated[float, Field(ge=-10000000, le=100000000)]
+    pile_head_level: Annotated[float, Field(ge=-1000, le=1000)]
     use_alternating_loads: Bool
-    max_force: confloat(ge=-100000, le=100000)
-    min_force: confloat(ge=-100000, le=100000)
-    limit_state_str: confloat(ge=0, le=100000)
-    limit_state_service: confloat(ge=0, le=100000)
-    pile_name: constr(min_length=1, max_length=10)
+    max_force: Annotated[float, Field(ge=-100000, le=100000)]
+    min_force: Annotated[float, Field(ge=-100000, le=100000)]
+    limit_state_str: Annotated[float, Field(ge=0, le=100000)]
+    limit_state_service: Annotated[float, Field(ge=0, le=100000)]
+    pile_name: Annotated[str, StringConstraints(min_length=1, max_length=100)]
 
 
 class PositionsBearingPiles(DSeriesNoParseSubStructure):
-    positions: List[PositionBearingPile] = []
+    positions: list[PositionBearingPile] = []
 
 
 class PositionsTensionPiles(DSeriesNoParseSubStructure):
-    positions: List[PositionTensionPile] = []
+    positions: list[PositionTensionPile] = []
 
 
 class CPTMeasureData(DFoundationsTableWrapper):
-    data: List[Dict[str, float]]
+    data: list[dict[str, float]]
 
 
 class ExcavationType(IntEnum):
@@ -405,7 +422,7 @@ class CPT(DFoundationsEnumStructure):
 
 
 class CPTList(DFoundationsCPTCollectionWrapper):
-    cpt_collection: List[CPT] = []
+    cpt_collection: list[CPT] = []
 
     def add_cpt(self, cpt: CPT):
         """Add CPT and return id.
@@ -427,34 +444,38 @@ class CPTList(DFoundationsCPTCollectionWrapper):
 
 
 class CalculationOptions(DSeriesNoParseSubStructure):
-
     # Rigidity of superstructure
     is_rigid: Bool = Bool.TRUE
 
     # Transformation
-    max_allowed_settlement_lim_state_str: confloat(ge=0, le=100000) = 0
-    max_allowed_rel_rotation_lim_state_str: confloat(ge=0.0001, le=10000) = 0.0001
-    max_allowed_settlement_lim_state_serv: confloat(ge=0, le=100000) = 0
-    max_allowed_rel_rotation_lim_state_serv: confloat(ge=0.0001, le=10000) = 0.0001
+    max_allowed_settlement_lim_state_str: Annotated[float, Field(ge=0, le=100000)] = 0
+    max_allowed_rel_rotation_lim_state_str: Annotated[int, Field(ge=1, le=10000)] = 100
+    max_allowed_settlement_lim_state_serv: Annotated[float, Field(ge=0, le=100000)] = 0
+    max_allowed_rel_rotation_lim_state_serv: Annotated[int, Field(ge=1, le=10000)] = 300
 
     # Overrule parameters Bearing Piles
     is_xi3_overruled: Bool = Bool.FALSE
-    factor_xi3: Optional[confloat(ge=0.01, le=10)] = 2
+    factor_xi3: Annotated[float, Field(ge=0.01, le=10)] | None = 2
     is_xi4_overruled: Bool = Bool.FALSE
-    factor_xi4: Optional[confloat(ge=0.01, le=10)] = 2
+    factor_xi4: Annotated[float, Field(ge=0.01, le=10)] | None = 2
     is_gamma_b_overruled: Bool = Bool.FALSE
-    factor_gamma_b: Optional[confloat(ge=1, le=100)] = 2
+    factor_gamma_b: Annotated[float, Field(ge=1, le=100)] | None = 2
     is_gamma_s_overruled: Bool = Bool.FALSE
-    factor_gamma_s: Optional[confloat(ge=1, le=100)] = 2
+    factor_gamma_s: Annotated[float, Field(ge=1, le=100)] | None = 2
     is_gamma_fnk_overruled: Bool = Bool.FALSE
-    factor_gamma_fnk: Optional[confloat(ge=-100, le=100)] = 2
+    factor_gamma_fnk: Annotated[float, Field(ge=-100, le=100)] | None = 2
     is_area_overruled: Bool = Bool.FALSE
-    area: Optional[confloat(ge=0, le=100000)] = 1000
+    area: Annotated[float, Field(ge=0, le=100000)] | None = 1000
+    is_qbmax_overruled: Bool = Bool.FALSE
+    qbmax: Annotated[float, Field(ge=0, le=100)] | None = 15
+    is_qcza_low_overruled: Bool = Bool.FALSE
+    qcza_low: Annotated[float, Field(ge=0, le=100)] | None = 12
+    is_qcza_high_overruled: Bool = Bool.FALSE
+    qcza_high: Annotated[float, Field(ge=0, le=100)] | None = 15
     is_ea_gem_overruled: Bool = Bool.FALSE
-    ea_gem: Optional[confloat(ge=1)] = 100000
+    ea_gem: Annotated[float, Field(ge=1)] | None = 100000
 
     # Model options combined
-    is_suppress_qc_reduction: Bool = Bool.FALSE
     is_overrule_excavation: Bool = Bool.FALSE
     use_pile_group: Bool = Bool.TRUE
     is_write_intermediate_results: Bool = Bool.FALSE
@@ -464,52 +485,35 @@ class CalculationOptions(DSeriesNoParseSubStructure):
 
     # Overrule parameters Shallow foundations
     is_gamma_g_str_overruled: Bool = Bool.FALSE
-    factor_gamma_g_str: Optional[confloat(ge=0.01, le=100)] = 1.0
+    factor_gamma_g_str: Annotated[float, Field(ge=0.01, le=100)] | None = 1.0
     is_gamma_coh_overruled: Bool = Bool.FALSE
-    factor_gamma_coh: Optional[confloat(ge=0.01, le=100)] = 1.0
+    factor_gamma_coh: Annotated[float, Field(ge=0.01, le=100)] | None = 1.0
     is_gamma_phi_overruled: Bool = Bool.FALSE
-    factor_gamma_phi: Optional[confloat(ge=0.01, le=100)] = 1.0
+    factor_gamma_phi: Annotated[float, Field(ge=0.01, le=100)] | None = 1.0
     is_gamma_fundr_overruled: Bool = Bool.FALSE
-    factor_gamma_fundr: Optional[confloat(ge=0.01, le=100)] = 1.0
+    factor_gamma_fundr: Annotated[float, Field(ge=0.01, le=100)] | None = 1.0
     is_gamma_g_sls_overruled: Bool = Bool.FALSE
-    factor_gamma_g_sls: Optional[confloat(ge=0.01, le=100)] = 1.0
+    factor_gamma_g_sls: Annotated[float, Field(ge=0.01, le=100)] | None = 1.0
     is_gamma_cc_overruled: Bool = Bool.FALSE
-    factor_gamma_cc: Optional[confloat(ge=0.01, le=100)] = 1.0
+    factor_gamma_cc: Annotated[float, Field(ge=0.01, le=100)] | None = 1.0
     is_gamma_ca_overruled: Bool = Bool.FALSE
-    factor_gamma_ca: Optional[confloat(ge=0.01, le=100)] = 1.0
+    factor_gamma_ca: Annotated[float, Field(ge=0.01, le=100)] | None = 1.0
     is_keep_length_constant: Bool = Bool.FALSE
     use_5_percent_limit: Bool = Bool.FALSE
-    load_factor_between_limit_1_and_2: confloat(ge=0.5, le=1) = 0.833
+    load_factor_between_limit_1_and_2: Annotated[float, Field(ge=0.5, le=1)] = 0.833
 
     # Overrule parameters Tension Piles
-    unit_weight_water: confloat(ge=0.01, le=20) = 9.81
+    unit_weight_water: Annotated[float, Field(ge=0.01, le=20)] = 9.81
     use_compaction: Bool = Bool.FALSE
     is_gamma_var_overruled: Bool = Bool.FALSE
-    factor_gamma_var: Optional[confloat(ge=0.01, le=100)] = 1.0
+    factor_gamma_var: Annotated[float, Field(ge=0.01, le=100)] | None = 1.0
     is_gamma_st_overruled: Bool = Bool.FALSE
-    factor_gamma_st: Optional[confloat(ge=0.01, le=100)] = 1.0
+    factor_gamma_st: Annotated[float, Field(ge=0.01, le=100)] | None = 1.0
     is_gamma_gamma_overruled: Bool = Bool.FALSE
-    factor_gamma_gamma: Optional[confloat(ge=0.01, le=100)] = 1.0
-    surcharge: confloat(ge=0, le=1e7) = 0
+    factor_gamma_gamma: Annotated[float, Field(ge=0.01, le=100)] | None = 1.0
+    surcharge: Annotated[float, Field(ge=0, le=1e7)] = 0
     use_piezometric_levels: Bool = Bool.TRUE
 
-    # Model options Bearing Piles BE
-    is_xi3_bpb_overruled: Bool = Bool.FALSE
-    factor_xi3_bpb: confloat(ge=0.01, le=10) = 1.0
-    is_xi4_bpb_overruled: Bool = Bool.FALSE
-    factor_xi4_bpb: confloat(ge=0.01, le=10) = 1.0
-    is_gamma_rd_overruled: Bool = Bool.FALSE
-    factor_gamma_rd: confloat(ge=1, le=100) = 1.0
-    is_gamma_b_bpb_overruled: Bool = Bool.FALSE
-    factor_gamma_b_bpb: confloat(ge=1, le=100) = 1.0
-    is_gamma_s_bpb_overruled: Bool = Bool.FALSE
-    factor_gamma_s_bpb: confloat(ge=1, le=100) = 1.0
-    suppress_all_qc_reduction_bp: Bool = Bool.FALSE
-    use_quality_assurance: Bool = Bool.FALSE
-    area_covered_per_cpt: confloat(ge=0) = 1000
-    is_beta_bpb_overruled: Bool = Bool.FALSE
-    factor_beat_bpb: confloat(ge=0.0, le=10) = 0
-
     def __init__(self, *args, **kwargs):
         """If defaults are overriden, update
         the related toggle fields as well.
@@ -519,7 +523,8 @@ class CalculationOptions(DSeriesNoParseSubStructure):
             if value is None:
                 continue  # Nones will be passed by default settings
             toggle_field = self.find_toggle(field)
-            if toggle_field in self.__fields__:
+            fields = self.model_fields
+            if toggle_field in fields:
                 toggles[toggle_field] = Bool.TRUE
         kwargs.update(toggles)
         super().__init__(*args, **kwargs)
@@ -536,11 +541,16 @@ class ModelTypeEnum(IntEnum):
     BEARING_PILES = 0
     TENSION_PILES = 1
     SHALLOW_FOUNDATIONS = 2
-    BEARING_PILES_BELGIAN = 3
 
 
+"""Note that CuValues is only relevant for Shallow Foundations, which is not supported."""
+class CuValuesEnum(IntEnum):
+    CU_VALUES_BASED_ON_CPTS = 0
+    CU_VALUES_MANUAL = 1
+
 class ModelType(DFoundationsInlineProperties):
     model: ModelTypeEnum = ModelTypeEnum.BEARING_PILES
+    cu_values: CuValuesEnum = CuValuesEnum.CU_VALUES_BASED_ON_CPTS
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
@@ -583,24 +593,24 @@ class PreliminaryDesign(DSeriesNoParseSubStructure):
     trajectory_end: float = -25.00
     trajectory_interval: float = 0.50
 
-    profiles: List[int] = []  # ids of Profiles
+    profiles: list[int] = []  # ids of Profiles
     # Can be single pile type only in case of verification
-    pile_types: List[int] = []  # ids of Piles
+    pile_types: list[int] = []  # ids of Piles
 
     # Only valid for Verification Design
-    cpt_test_level: Optional[float] = 0.0  # [m]
+    cpt_test_level: float | None = 0.0  # [m]
 
     # Only valid for Prelimary Design
-    net_bearing_capacity: Optional[int] = 0  # [kN]
+    net_bearing_capacity: int | None = 0  # [kN]
 
 
 class Version(DSerieVersion):
-    soil: int = 1005
-    d__foundations: int = 1015
+    soil: int = 1013
+    d__foundations: int = 1033
 
 
 class VersionExternal(DSeriesInlineMappedProperties):
-    dgsfoundationcalc____dll: str = "19.1.2.26122"
+    dgsfoundationcalc____dll: str = "23.1.0.40358"
 
 
 class DFoundationsInputStructure(DSeriesStructure):
@@ -613,24 +623,25 @@ class DFoundationsInputStructure(DSeriesStructure):
     run_identification: str = 6 * "\n"
     cpt_list: CPTList = CPTList()
     profiles: Profiles = Profiles()
+    user_classification_method: str = cleandoc(
+        """          
+        [USER CLASSIFICATION METHOD]
+        0
+        [END OF USER CLASSIFICATION METHOD]
+        """
+    )
     slopes: str = cleandoc(
         """
             0 = number of items
         """
     )
-    types___bearing_piles: Union[List[TypesBearingPiles], str] = cleandoc(
+    types___bearing_piles: list[TypesBearingPiles] | str = cleandoc(
         """
         -1 : pile type shown in main graph
             0 = number of items
         """
     )
-    types___bearing_piles_belgian: str = cleandoc(
-        """
-        -1 : pile type shown in main graph
-            0 = number of items
-        """
-    )
-    types___tension_piles_cur: Union[List[TypesTensionPiles], str] = cleandoc(
+    types___tension_piles_cur: list[TypesTensionPiles] | str = cleandoc(
         """
         -1 : pile type shown in main graph
             0 = number of items
@@ -646,63 +657,19 @@ class DFoundationsInputStructure(DSeriesStructure):
             0 = number of items
         """
     )
-    positions___bearing_piles: Union[PositionsBearingPiles, str] = PositionsBearingPiles()
-    positions___bearing_piles_belgian: str = cleandoc(
-        """
-        [TABLE]
-        [COLUMN INDICATION]
-        index
-        X
-        Y
-        PileHeadLevel
-        Surcharge
-        LimitStateStrGeo
-        LimitStateService
-        PileName
-        [END OF COLUMN INDICATION]
-        [DATA]
-        [END OF DATA]
-        [END OF TABLE]
-        """
-    )
-    positions___tension_piles_cur: Union[
-        PositionsTensionPiles, str
-    ] = PositionsTensionPiles()
+    positions___bearing_piles: PositionsBearingPiles | str = PositionsBearingPiles()
+
+    positions___tension_piles_cur: PositionsTensionPiles | str = PositionsTensionPiles()
     positions___shallow_foundations: str = cleandoc(
         """
         [TABLE]
-        [COLUMN INDICATION]
-        index
-        X
-        Y
-        Angle
-        FoundationType
-        Load
-        Profile
-        Slope
-        PileName
-        [END OF COLUMN INDICATION]
-        [DATA]
-        [END OF DATA]
+        DataCount=0
         [END OF TABLE]
         """
     )
-    calculation_options: Union[CalculationOptions, str] = CalculationOptions()
+    calculation_options: CalculationOptions | str = CalculationOptions()
     calculationtype: CalculationType = CalculationType()
-    preliminary_design: Union[PreliminaryDesign, str] = PreliminaryDesign()
-    de_beer: str = cleandoc(
-        """
-          0.0357 : Cone diameter [m]
-            1.00 : Installation factor [-]
-           1.000 : Scale factor [-]
-           -4.00 : Trajectory begin [m]
-          -20.00 : Trajectory end [m]
-            1.00 : Trajectory interval [m]
-        0 : Number of Profiles selected for calculation
-            -1 : No pile type selected
-        0 : Lambda overruled = FALSE
-        """
-    )
+    preliminary_design: PreliminaryDesign | str = PreliminaryDesign()
     location_map: str = cleandoc(
         """
          0.0000
@@ -719,7 +686,7 @@ class DFoundationsInputStructure(DSeriesStructure):
 
 
 class DFoundationsNenPileResultsTable(DFoundationsTableWrapper):
-    data: List[Dict[str, Union[int, float, str]]] = []
+    data: list[dict[str, int | float | str]] = []
 
 
 class DFoundationsCalculationParametersBearingPilesEC7(DSeriesInlineProperties):
@@ -769,7 +736,9 @@ class DFoundationsNenPileResults(DFoundationsInlineProperties):
     min_value: float
     max_value: float
     nen_average_pile_factors: DFoundationsNenPileResultsTable
-    calculation_parameters_bearing_piles_ec_7: DFoundationsCalculationParametersBearingPilesEC7
+    calculation_parameters_bearing_piles_ec_7: (
+        DFoundationsCalculationParametersBearingPilesEC7
+    )
 
     @classmethod
     def header_lines(cls) -> int:
@@ -784,20 +753,20 @@ class DFoundationsNenPileResults(DFoundationsInlineProperties):
 
 class DFoundationsGlobalNenResults(DFoundationsInlineProperties):
     wd1b: float
-    betad1b: float
     w2d: float
-    betad2: float
+    reciprocal_max_relative_rotation_calc_1B: float
+    reciprocal_max_relative_rotation_calc_2: float
 
 
 class DFoundationsVerificationResults(DSeriesStructure):
-    global_nen_results: Optional[DFoundationsGlobalNenResults]
-    demands_nen__en: Optional[str]
-    nen_pile_results: Optional[DFoundationsNenPileResults]
+    global_nen_results: DFoundationsGlobalNenResults | None = None
+    demands_nen__en: str | None = None
+    nen_pile_results: DFoundationsNenPileResults | None = None
 
-    verification_results_tp_load__settlement_curve_1b: Optional[str]
-    verification_results_tp_1a: Optional[str]
-    verification_results_tp_1b2: Optional[str]
-    verification_results_tp_load__settlement_curve_2: Optional[str]
+    verification_results_tp_load__settlement_curve_1b: str | None = None
+    verification_results_tp_1a: str | None = None
+    verification_results_tp_1b2: str | None = None
+    verification_results_tp_load__settlement_curve_2: str | None = None
 
 
 # endregion
@@ -818,26 +787,28 @@ class DFoundationsCalculationWarnings(DSeriesTreeStructure):
     is_warning_sf_slope_not_relevant_given: Bool
     is_warning_nen_sf_placement_depth_too_deep: Bool
     is_warning_nen_sf_placement_depth_too_shallow: Bool
+    is_warning_nen_bp_positive_skin_friction_zone_given: Bool
+    is_warning_sf_foundation_level_for_punch_to_deep_for_slope_given: Bool
 
 
 class DFoundationsDumpfileOutputStructure(DSeriesStructure):
-    results_at_cpt_test_level: Optional[str]
-    verification_results: Optional[DFoundationsVerificationResults]
+    results_at_cpt_test_level: str | None = None
+    verification_results: DFoundationsVerificationResults | None = None
 
-    calculation_parameters_tension_piles: Optional[str]
-    verification_results_tp: Optional[DFoundationsVerificationResults]
+    calculation_parameters_tension_piles: str | None = None
+    verification_results_tp: DFoundationsVerificationResults | None = None
 
-    footnote_warnings: Optional[str]
-    preliminary_design_results: Optional[str]
-    verification_results_sf: Optional[str]
-    verification_results_tp_1b2: Optional[str]
-    verification_design_results: Optional[str]
+    pile_type_dimensions_warnings: str | None = None
+    preliminary_design_results: str | None = None
+    verification_results_sf: str | None = None
+    verification_results_tp_1b2: str | None = None
+    verification_design_results: str | None = None
+    calculation_warnings: DFoundationsCalculationWarnings | None = None
 
 
 class DFoundationsStructure(DSeriesStructure):
     input_data: DFoundationsInputStructure = DFoundationsInputStructure()
-    dumpfile_output: Optional[DFoundationsDumpfileOutputStructure]
-    calculation_warnings: Optional[DFoundationsCalculationWarnings]
+    dumpfile_output: DFoundationsDumpfileOutputStructure | None = None
 
 
 class DFoundationsDumpStructure(DSeriesStructure):
