@@ -2,7 +2,7 @@ import abc
 import re
 from enum import Enum
 from pathlib import Path
-from typing import BinaryIO, Dict, List, Optional, Set, Type, Union
+from typing import BinaryIO
 
 from pydantic import DirectoryPath, FilePath
 
@@ -18,10 +18,11 @@ from .internal import (
     DGeoFlowResult,
     DGeoFlowStructure,
     GroundwaterFlowResult,
+    InternalPipeTrajectory,
     PersistableSoil,
     PersistableSoilLayer,
     PipeLengthResult,
-    PipeTrajectory,
+    Scenario,
     SoilCollection,
     SoilLayerCollection,
 )
@@ -43,6 +44,7 @@ class DGeoFlowModel(BaseModel):
 
     current_scenario: int = -1
     current_scenario_index: int = 0
+    current_stage_index: int = 0
     current_calculation_index: int = 0
     datastructure: DGeoFlowStructure = DGeoFlowStructure()
     current_id: int = -1
@@ -52,15 +54,19 @@ class DGeoFlowModel(BaseModel):
         self.current_id = self.datastructure.get_unique_id()
 
     @property
-    def parser_provider_type(self) -> Type[DGeoFlowParserProvider]:
+    def parser_provider_type(self) -> type[DGeoFlowParserProvider]:
         return DGeoFlowParserProvider
 
     @property
-    def console_path(self) -> Path:
-        return Path("DGeoFlowConsole/DGeoFlow Console.exe")
+    def default_console_path(self) -> Path:
+        return Path("DGeoFlowConsole/D-GeoFlow Console.exe")
 
     @property
-    def console_flags_post(self) -> List[str]:
+    def custom_console_path(self) -> Path:
+        return self.get_meta_property("dgeoflow_console_path")
+
+    @property
+    def console_flags_post(self) -> list[str]:
         return [
             str(self.current_scenario_index + 1),
             str(self.current_calculation_index + 1),
@@ -93,7 +99,7 @@ class DGeoFlowModel(BaseModel):
             self.current_scenario_index, self.current_calculation_index
         )
 
-    def get_result(self, scenario_index: int, calculation_index: int) -> Dict:
+    def get_result(self, scenario_index: int, calculation_index: int) -> dict:
         """
         Returns the results of a scenario. Calculation results are based on analysis type and calculation type.
 
@@ -127,7 +133,7 @@ class DGeoFlowModel(BaseModel):
 
         raise ValueError(f"No result found for result id {scenario_index}")
 
-    def serialize(self, location: Union[FilePath, DirectoryPath, BinaryIO]):
+    def serialize(self, location: FilePath | DirectoryPath | BinaryIO):
         """Support serializing to directory while developing for debugging purposes."""
         if isinstance(location, Path) and location.is_dir():
             serializer = DGeoFlowInputSerializer(ds=self.datastructure)
@@ -138,31 +144,6 @@ class DGeoFlowModel(BaseModel):
         if isinstance(location, Path):
             self.filename = location
 
-    def copy_scenario(self, label: str, notes: str, set_current=True) -> int:
-        """Copy an existing scenario and add it to the model.
-
-        Args:
-            label: Label for the scenario
-            notes: Notes for the scenario
-            set_current: Whether to make the new scenario the current scenario.
-
-        Returns:
-            the id of the new scenario
-        """
-        new_id = self._get_next_id()
-        new_scenario_id, new_unique_id = self.datastructure.duplicate_scenario(
-            self.current_scenario, label, notes, new_id
-        )
-
-        if set_current:
-            self.current_scenario = new_scenario_id
-            self.current_scenario_index += 1
-        self.current_id = new_unique_id
-        return new_scenario_id
-
-    def add_point(self, point: Point, scenario=None) -> int:
-        """Add point, which should be unique in the model and return the created point id."""
-
     def add_soil(self, soil: Soil) -> int:
         """
         Add a new soil to the model. The code must be unique, the id will be generated
@@ -212,7 +193,7 @@ class DGeoFlowModel(BaseModel):
 
     def add_layer(
         self,
-        points: List[Point],
+        points: list[Point],
         soil_code: str,
         label: str = "",
         notes: str = "",
@@ -222,7 +203,7 @@ class DGeoFlowModel(BaseModel):
         Add a soil layer to the model
 
         Args:
-            points (List[Point]): list of Point classes, in clockwise order (non closed simple polygon)
+            points (list[Point]): list of Point classes, in clockwise order (non closed simple polygon)
             soil_code (str): code of the soil for this layer
             label (str): label defaults to empty string
             notes (str): notes defaults to empty string
@@ -231,7 +212,7 @@ class DGeoFlowModel(BaseModel):
         Returns:
             int: id of the added layer
         """
-        scenario_id = scenario_id if scenario_id else self.current_scenario
+        scenario_id = scenario_id if scenario_id is not None else self.current_scenario
 
         if not self.datastructure.has_scenario(scenario_id):
             raise IndexError(f"scenario {scenario_id} is not available")
@@ -274,7 +255,7 @@ class DGeoFlowModel(BaseModel):
         Returns:
             int: id of the added meshproperties collection
         """
-        scenario_id = scenario_id if scenario_id else self.current_scenario
+        scenario_id = scenario_id if scenario_id is not None else self.current_scenario
         meshpropertiescollection = self.datastructure.mesh_properties[scenario_id]
 
         persistable_layer = self.get_layer(scenario_id, layer_id)
@@ -286,7 +267,7 @@ class DGeoFlowModel(BaseModel):
 
     def add_boundary_condition(
         self,
-        points: List[Point],
+        points: list[Point],
         head_level: float,
         label: str = "",
         notes: str = "",
@@ -296,7 +277,7 @@ class DGeoFlowModel(BaseModel):
         Add boundary conditions to the model
 
         Args:
-            points (List[Point]): list of Point classes, in clockwise order (non closed simple polygon)
+            points (list[Point]): list of Point classes, in clockwise order (non closed simple polygon)
             head_level (float): level of the hydraulic head for the boundary condition
             label (str): label defaults to empty string
             notes (str): notes defaults to empty string
@@ -305,7 +286,7 @@ class DGeoFlowModel(BaseModel):
         Returns:
             int: id of the boundary conditions collection
         """
-        scenario_id = scenario_id if scenario_id else self.current_scenario
+        scenario_id = scenario_id if scenario_id is not None else self.current_scenario
         boundary_conditions = self.datastructure.boundary_conditions[scenario_id]
 
         boundary_condition_id = self._get_next_id()
@@ -315,57 +296,96 @@ class DGeoFlowModel(BaseModel):
 
         return boundary_condition_id
 
+    @property
+    def scenarios(self) -> list[Scenario]:
+        return self.datastructure.scenarios
+
     def add_scenario(
-        self,
-        scenario_index: int = None,
-        boundaryconditions_id: int = None,
-        soillayers_id: int = None,
-        geometry_id: int = None,
-        meshproperties_id: int = None,
-        label: str = "",
-        notes: str = "",
-        calculations_notes: str = "",
-        stage_notes: str = "",
-        calculations_label: str = None,
-        stage_label: str = None,
+        self, label: str = "Scenario", notes: str = "", set_current: bool = True
     ) -> int:
-        """
-        Add a scenario to the model
+        """Add a new scenario to the model.
 
         Args:
-            scenario_index (int): scenario to add to, defaults to 0
-            boundaryconditions_id (int): id of the boundary conditions collection to add to the scenario
-            soillayers_id (int): id of the soil layers to add to the scenario
-            geometry_id (int): id of the geometry to add to the scenario
-            meshproperties_id (int): id of the mesh properties to add to the scenario
-            label (str): label of the scenario, defaults to empty string
-            notes (str): notes of the scenario, defaults to empty string
-            calculations_notes (str): notes of the calculation, defaults to empty string
-            stage_notes (str): notes of the stage, defaults to empty string
-            calculations_label (str): label of the calculation, defaults to empty string
-            stage_label (str): label of the stage, defaults to empty string
+            label: Label for the scenario.
+            notes: Notes for the scenario.
+            set_current: Whether to make the new scenario the current scenario.
 
         Returns:
-            int: id of the scenario
+            the id of the new stage
         """
-
-        scenarios = self.datastructure.scenarios[scenario_index]
-
-        scenarios.Label = label
-        scenarios.Notes = notes
-        scenarios.GeometryId = geometry_id
-        scenarios.SoilLayersId = soillayers_id
-        scenarios.add_calculation(
-            label=calculations_label,
-            notes=calculations_notes,
-            mesh_properties_id=meshproperties_id,
+        new_id = self._get_next_id()
+        new_scenario_id, new_unique_id = self.datastructure.add_default_scenario(
+            label, notes, new_id
         )
-        scenarios.add_stage(
-            label=stage_label,
-            notes=stage_notes,
-            boundaryconditions_collection_id=boundaryconditions_id,
+
+        if set_current:
+            self.current_scenario = new_scenario_id
+            self.current_stage_index = 0
+            self.current_calculation_index = 0
+
+        self.current_id = new_unique_id
+        return new_scenario_id
+
+    def add_stage(
+        self,
+        scenario_index: int | None = None,
+        label: str = "Stage",
+        notes: str = "",
+        set_current=True,
+    ) -> int:
+        """Add a new stage to the model at the given scenario index.
+
+        Args:
+            scenario_index: The scenario index to add the stage to, defaults to the current scenario.
+            label: Label for the stage.
+            notes: Notes for the stage.
+            set_current: Whether to make the new stage the current stage.
+
+        Returns:
+            the id of the new stage
+        """
+        scenario_index = (
+            scenario_index if scenario_index is not None else self.current_scenario
         )
-        return int(scenarios.Id)
+
+        new_id = self._get_next_id()
+        new_stage_index = self.datastructure.add_default_stage(
+            scenario_index, label, notes, new_id
+        )
+
+        if set_current:
+            self.current_stage_index = new_stage_index
+        return new_stage_index
+
+    def add_calculation(
+        self,
+        scenario_index: int | None = None,
+        label: str = "Calculation",
+        notes: str = "",
+        set_current: bool = True,
+    ) -> int:
+        """Add a new calculation to the model.
+
+        Args:
+            scenario_index: The scenario index to add the calculation to, defaults to the current scenario.
+            label: Label for the calculation.
+            notes: Notes for the calculation.
+            set_current: Whether to make the new calculation the current calculation.
+
+        Returns:
+            the id of the new stage
+        """
+        scenario_index = (
+            scenario_index if scenario_index is not None else self.current_scenario
+        )
+
+        new_calculation_index = self.datastructure.add_default_calculation(
+            scenario_index, label, notes
+        )
+
+        if set_current:
+            self.current_calculation_index = new_calculation_index
+        return new_calculation_index
 
     def set_calculation_type(
         self,
@@ -390,7 +410,7 @@ class DGeoFlowModel(BaseModel):
         self,
         scenario_index: int = 0,
         calculation_index: int = 0,
-        pipe_trajectory: PipeTrajectory = None,
+        pipe_trajectory: InternalPipeTrajectory = None,
     ) -> None:
         """
         Sets the pipe trajectory for a calculation.
