@@ -1,15 +1,19 @@
+"""
+The internal data model structure.
+"""
+
 from collections import defaultdict
 from datetime import date, datetime
 from enum import Enum
 from itertools import chain
 from math import isfinite
-from typing import Dict, List, Optional, Set, Tuple, Union
 
-from pydantic import ValidationError, confloat, conlist, root_validator, validator
+from pydantic import ConfigDict, Field, field_validator, model_validator
+from typing_extensions import Annotated
 
-from geolib import BaseModelStructure
 from geolib import __version__ as version
 from geolib.geometry import Point
+from geolib.models import BaseModelStructure
 from geolib.soils import Soil, StorageParameters
 from geolib.utils import snake_to_camel
 
@@ -19,13 +23,19 @@ from .utils import children
 
 class DGeoFlowBaseModelStructure(BaseModelStructure):
     def dict(_, *args, **kwargs):
-        data = super().dict(*args, **kwargs)
+        data = super().model_dump(*args, **kwargs)
         return {
             k: "NaN" if isinstance(v, float) and not isfinite(v) else v
             for k, v in data.items()
         }
 
 
+def transform_id_to_str(value) -> str:
+    if value is None:
+        return None
+    return str(value)
+
+
 class DGeoFlowSubStructure(DGeoFlowBaseModelStructure):
     @classmethod
     def structure_name(cls):
@@ -52,7 +62,7 @@ class PersistableStochasticParameter(DGeoFlowBaseModelStructure):
     StandardDeviation: float = 0.0
 
 
-class PersistableShadingType(Enum):
+class PersistableShadingTypeEnum(Enum):
     DIAGONAL_A = "DiagonalA"
     DIAGONAL_B = "DiagonalB"
     DIAGONAL_C = "DiagonalC"
@@ -67,14 +77,16 @@ class PersistableShadingType(Enum):
 
 
 class PersistableSoilVisualization(DGeoFlowBaseModelStructure):
-    Color: Optional[str]
-    PersistableShadingType: Optional[PersistableShadingType]
-    SoilId: Optional[str]
+    Color: str | None
+    PersistableShadingType: PersistableShadingTypeEnum | None
+    SoilId: str | None
+
+    id_validator = field_validator("SoilId", mode="before")(transform_id_to_str)
 
 
 class SoilVisualisation(DGeoFlowBaseModelStructure):
-    ContentVersion: Optional[str] = "2"
-    SoilVisualizations: Optional[List[Optional[PersistableSoilVisualization]]] = []
+    ContentVersion: str | None = "2"
+    SoilVisualizations: list[PersistableSoilVisualization | None] | None = []
 
     @classmethod
     def structure_name(cls) -> str:
@@ -82,8 +94,12 @@ class SoilVisualisation(DGeoFlowBaseModelStructure):
 
 
 class PersistableSoilLayer(DGeoFlowBaseModelStructure):
-    LayerId: Optional[str]
-    SoilId: Optional[str]
+    LayerId: str | None = None
+    SoilId: str | None = None
+
+    id_validator = field_validator("LayerId", "SoilId", mode="before")(
+        transform_id_to_str
+    )
 
 
 class SoilLayerCollection(DGeoFlowSubStructure):
@@ -97,16 +113,18 @@ class SoilLayerCollection(DGeoFlowSubStructure):
     def structure_group(cls) -> str:
         return "soillayers"
 
-    ContentVersion: Optional[str] = "2"
-    Id: Optional[str]
-    SoilLayers: List[PersistableSoilLayer] = []
+    ContentVersion: str | None = "2"
+    Id: str | None = None
+    SoilLayers: list[PersistableSoilLayer] = []
+
+    id_validator = field_validator("Id", mode="before")(transform_id_to_str)
 
     def add_soillayer(self, layer_id: str, soil_id: str) -> PersistableSoilLayer:
         psl = PersistableSoilLayer(LayerId=layer_id, SoilId=soil_id)
         self.SoilLayers.append(psl)
         return psl
 
-    def get_ids(self, exclude_soil_layer_id: Optional[int]) -> Set[str]:
+    def get_ids(self, exclude_soil_layer_id: int | None) -> set[str]:
         if exclude_soil_layer_id is not None:
             exclude_soil_layer_id = str(exclude_soil_layer_id)
         return {
@@ -124,12 +142,14 @@ class PersistableSoil(DGeoFlowBaseModelStructure):
     HorizontalPermeability: float = 0.001
     VerticalPermeability: float = 0.001
 
+    id_validator = field_validator("Id", mode="before")(transform_id_to_str)
+
 
 class SoilCollection(DGeoFlowSubStructure):
     """soils.json"""
 
-    ContentVersion: Optional[str] = "2"
-    Soils: List[PersistableSoil] = [
+    ContentVersion: str | None = "2"
+    Soils: list[PersistableSoil] = [
         PersistableSoil(
             Code="H_Aa_ht_new",
             Id="2",
@@ -296,7 +316,7 @@ class SoilCollection(DGeoFlowSubStructure):
         raise ValueError(f"Soil code '{code}' not found in the SoilCollection")
 
     def edit_soil_by_name(
-        self, name: Optional[str] = None, **kwargs: dict
+        self, name: str | None = None, **kwargs: dict
     ) -> PersistableSoil:
         """
         Update a soil, searching by name. This method will edit the first occurence of the name
@@ -332,22 +352,22 @@ class SoilCollection(DGeoFlowSubStructure):
 class ProjectInfo(DGeoFlowSubStructure):
     """projectinfo.json."""
 
-    Analyst: Optional[str] = ""
-    ApplicationCreated: Optional[str] = ""
-    ApplicationModified: Optional[str] = ""
-    ContentVersion: Optional[str] = "2"
-    Created: Optional[date] = datetime.now().date()
-    CrossSection: Optional[str] = ""
-    Date: Optional[date] = datetime.now().date()
-    IsDataValidated: Optional[bool] = False
-    LastModified: Optional[date] = datetime.now().date()
-    LastModifier: Optional[str] = "GEOLib"
-    Path: Optional[str] = ""
-    Project: Optional[str] = ""
-    Remarks: Optional[str] = f"Created with GEOLib {version}"
+    Analyst: str | None = ""
+    ApplicationCreated: str | None = ""
+    ApplicationModified: str | None = ""
+    ContentVersion: str | None = "2"
+    Created: date | None = datetime.now().date()
+    CrossSection: str | None = ""
+    Date: date | None = datetime.now().date()
+    IsDataValidated: bool | None = False
+    LastModified: date | None = datetime.now().date()
+    LastModifier: str | None = "GEOLib"
+    Path: str | None = ""
+    Project: str | None = ""
+    Remarks: str | None = f"Created with GEOLib {version}"
 
-    @validator("Created", "Date", "LastModified", pre=True, allow_reuse=True)
-    def nltime(cls, date: Union[date, str]) -> date:
+    @classmethod
+    def nltime(cls, date: date | str) -> date:
         if isinstance(date, str):
             position = date.index(max(date.split("-"), key=len))
             if position > 0:
@@ -356,19 +376,25 @@ class ProjectInfo(DGeoFlowSubStructure):
                 date = datetime.strptime(date, "%Y-%m-%d").date()
         return date
 
+    nltime_validator = field_validator("Created", "Date", "LastModified", mode="before")(
+        nltime
+    )
+
 
 class PersistablePoint(DGeoFlowBaseModelStructure):
-    X: Optional[float] = 0
-    Z: Optional[float] = 0
+    X: float | None = 0
+    Z: float | None = 0
 
 
 class PersistableLayer(DGeoFlowBaseModelStructure):
-    Id: Optional[str]
-    Label: Optional[str]
-    Notes: Optional[str]
-    Points: conlist(PersistablePoint, min_items=3)
+    Id: str | None = None
+    Label: str | None = None
+    Notes: str | None = None
+    Points: Annotated[list[PersistablePoint], Field(min_length=3)]
 
-    @validator("Points", pre=True, allow_reuse=True)
+    id_validator = field_validator("Id", mode="before")(transform_id_to_str)
+
+    @classmethod
     def polygon_checks(cls, points):
         """
         Todo:
@@ -381,6 +407,8 @@ class PersistableLayer(DGeoFlowBaseModelStructure):
         # 4. does it intersect other polygons
         return points
 
+    polygon_checks_validator = field_validator("Points", mode="before")(polygon_checks)
+
 
 class Geometry(DGeoFlowSubStructure):
     """geometries/geometry_x.json"""
@@ -393,9 +421,11 @@ class Geometry(DGeoFlowSubStructure):
     def structure_name(cls) -> str:
         return "geometry"
 
-    ContentVersion: Optional[str] = "2"
-    Id: Optional[str]
-    Layers: List[PersistableLayer] = []
+    ContentVersion: str | None = "2"
+    Id: str | None = None
+    Layers: list[PersistableLayer] = []
+
+    id_validator = field_validator("Id", mode="before")(transform_id_to_str)
 
     def contains_point(self, point: Point) -> bool:
         """
@@ -425,7 +455,7 @@ class Geometry(DGeoFlowSubStructure):
         raise ValueError(f"Layer id {id} not found in this geometry")
 
     def add_layer(
-        self, id: str, label: str, notes: str, points: List[Point]
+        self, id: str, label: str, notes: str, points: list[Point]
     ) -> PersistableLayer:
         """
         Add a new layer to the model. Layers are expected;
@@ -437,7 +467,7 @@ class Geometry(DGeoFlowSubStructure):
             id (str): id of the layer
             label (str): label of the layer
             notes (str): notes for the layers
-            points (List[Points]): list of Point classes
+            points (list[Points]): list of Point classes
 
         Returns:
             PersistableLayer: the layer as a persistable object
@@ -458,19 +488,23 @@ class PersistableFixedHeadBoundaryConditionProperties(DGeoFlowBaseModelStructure
 
 
 class PersistableBoundaryCondition(DGeoFlowBaseModelStructure):
-    Label: Optional[str]
-    Notes: Optional[str]
-    Id: Optional[str]
-    Points: conlist(PersistablePoint, min_items=2)
+    Label: str | None = None
+    Notes: str | None = None
+    Id: str | None = None
+    Points: Annotated[list[PersistablePoint], Field(min_length=2)]
     FixedHeadBoundaryConditionProperties: PersistableFixedHeadBoundaryConditionProperties
 
+    id_validator = field_validator("Id", mode="before")(transform_id_to_str)
+
 
 class BoundaryConditionCollection(DGeoFlowSubStructure):
     """boundaryconditions/boundaryconditions_x.json"""
 
-    ContentVersion: Optional[str] = "2"
-    Id: Optional[str]
-    BoundaryConditions: List[PersistableBoundaryCondition] = []
+    ContentVersion: str | None = "2"
+    Id: str | None = None
+    BoundaryConditions: list[PersistableBoundaryCondition] = []
+
+    id_validator = field_validator("Id", mode="before")(transform_id_to_str)
 
     @classmethod
     def structure_group(cls) -> str:
@@ -501,7 +535,7 @@ class BoundaryConditionCollection(DGeoFlowSubStructure):
         return False
 
     def add_boundary_condition(
-        self, id: int, label: str, notes: str, points: List[Point], head_level: float
+        self, id: int, label: str, notes: str, points: list[Point], head_level: float
     ) -> PersistableBoundaryCondition:
         pbc_properties = PersistableFixedHeadBoundaryConditionProperties(
             HeadLevel=head_level
@@ -518,9 +552,9 @@ class BoundaryConditionCollection(DGeoFlowSubStructure):
 
 
 class PersistableStage(DGeoFlowBaseModelStructure):
-    Label: Optional[str]
-    Notes: Optional[str]
-    BoundaryConditionCollectionId: Optional[str]
+    Label: str | None = None
+    Notes: str | None = None
+    BoundaryConditionCollectionId: str | None = None
 
 
 class ErosionDirectionEnum(Enum):
@@ -528,55 +562,67 @@ class ErosionDirectionEnum(Enum):
     RIGHT_TO_LEFT = "RightToLeft"
 
 
-class PipeTrajectory(DGeoFlowBaseModelStructure):
-    Label: Optional[str]
-    Notes: Optional[str]
-    D70: Optional[float]
-    Points: Optional[List[PersistablePoint]]
-    ErosionDirection: Optional[ErosionDirectionEnum] = ErosionDirectionEnum.RIGHT_TO_LEFT
-    ElementSize: Optional[float]
+class InternalPipeTrajectory(DGeoFlowBaseModelStructure):
+    Label: str | None = None
+    Notes: str | None = None
+    D70: float | None = None
+    Points: list[PersistablePoint] | None = None
+    ErosionDirection: ErosionDirectionEnum | None = ErosionDirectionEnum.RIGHT_TO_LEFT
+    ElementSize: float | None = None
 
 
 class PersistableCriticalHeadSearchSpace(DGeoFlowBaseModelStructure):
-    MinimumHeadLevel: Optional[float] = 0
-    MaximumHeadLevel: Optional[float] = 1
-    StepSize: Optional[float] = 0.1
+    MinimumHeadLevel: float | None = 0
+    MaximumHeadLevel: float | None = 1
+    StepSize: float | None = 0.1
 
 
 class PersistableCalculation(DGeoFlowBaseModelStructure):
-    Label: Optional[str]
-    Notes: Optional[str]
-    CalculationType: Optional[CalculationTypeEnum] = CalculationTypeEnum.GROUNDWATER_FLOW
-    CriticalHeadId: Optional[str]
-    CriticalHeadSearchSpace: Optional[
-        PersistableCriticalHeadSearchSpace
-    ] = PersistableCriticalHeadSearchSpace()
-    PipeTrajectory: Optional[PipeTrajectory]
-    MeshPropertiesId: Optional[str]
-    ResultsId: Optional[str]
+    Label: str | None = None
+    Notes: str | None = None
+    CalculationType: CalculationTypeEnum | None = CalculationTypeEnum.GROUNDWATER_FLOW
+    CriticalHeadId: str | None = None
+    CriticalHeadSearchSpace: PersistableCriticalHeadSearchSpace | None = (
+        PersistableCriticalHeadSearchSpace()
+    )
+    PipeTrajectory: InternalPipeTrajectory | None = None
+    MeshPropertiesId: str | None = None
+    ResultsId: str | None = None
+
+    id_validator = field_validator(
+        "CriticalHeadId", "MeshPropertiesId", "ResultsId", mode="before"
+    )(transform_id_to_str)
 
 
 class NodeResult(DGeoFlowBaseModelStructure):
-    Point: Optional[PersistablePoint] = None
+    Point: PersistablePoint | None = None
     TotalPorePressure: float = 1
     HydraulicDischarge: float = 1
     HydraulicHead: float = 1
 
 
 class ElementResult(DGeoFlowBaseModelStructure):
-    NodeResults: Optional[List[NodeResult]] = []
+    NodeResults: list[NodeResult] | None = []
+
+
+class PersistablePhreaticLineSegment(DGeoFlowBaseModelStructure):
+    Start: PersistablePoint | None = None
+    End: PersistablePoint | None = None
 
 
 class PipeElementResult(DGeoFlowBaseModelStructure):
-    Nodes: Optional[List[PersistablePoint]] = []
-    IsActive: Optional[bool]
-    Height: Optional[float]
+    Nodes: list[PersistablePoint] | None = []
+    IsActive: bool | None = None
+    Height: float | None = None
 
 
 class GroundwaterFlowResult(DGeoFlowSubStructure):
-    Id: Optional[str] = None
-    Elements: Optional[List[ElementResult]] = []
-    ContentVersion: Optional[str] = "2"
+    Id: str | None = None
+    Elements: list[ElementResult] | None = []
+    PhreaticLineSegments: list[PersistablePhreaticLineSegment] | None = []
+    ContentVersion: str | None = "2"
+
+    id_validator = field_validator("Id", mode="before")(transform_id_to_str)
 
     @classmethod
     def structure_group(cls) -> str:
@@ -584,11 +630,14 @@ class GroundwaterFlowResult(DGeoFlowSubStructure):
 
 
 class PipeLengthResult(DGeoFlowSubStructure):
-    Id: Optional[str] = None
-    PipeLength: Optional[float]
-    Elements: Optional[List[ElementResult]] = []
-    PipeElements: Optional[List[PipeElementResult]] = []
-    ContentVersion: Optional[str] = "2"
+    Id: str | None = None
+    PipeLength: float | None = None
+    Elements: list[ElementResult] | None = []
+    PhreaticLineSegments: list[PersistablePhreaticLineSegment] | None = []
+    PipeElements: list[PipeElementResult] | None = []
+    ContentVersion: str | None = "2"
+
+    id_validator = field_validator("Id", mode="before")(transform_id_to_str)
 
     @classmethod
     def structure_group(cls) -> str:
@@ -596,32 +645,39 @@ class PipeLengthResult(DGeoFlowSubStructure):
 
 
 class CriticalHeadResult(DGeoFlowSubStructure):
-    Id: Optional[str] = None
-    PipeLength: Optional[float]
-    CriticalHead: Optional[float]
-    Elements: Optional[List[ElementResult]] = []
-    PipeElements: Optional[List[PipeElementResult]] = []
-    ContentVersion: Optional[str] = "2"
+    Id: str | None = None
+    PipeLength: float | None = None
+    CriticalHead: float | None = None
+    Elements: list[ElementResult] | None = []
+    PhreaticLineSegments: list[PersistablePhreaticLineSegment] | None = []
+    PipeElements: list[PipeElementResult] | None = []
+    ContentVersion: str | None = "2"
+
+    id_validator = field_validator("Id", mode="before")(transform_id_to_str)
 
     @classmethod
     def structure_group(cls) -> str:
         return "results/criticalhead/"
 
 
-DGeoFlowResult = Union[GroundwaterFlowResult, PipeLengthResult, CriticalHeadResult]
+DGeoFlowResult = GroundwaterFlowResult | PipeLengthResult | CriticalHeadResult
 
 
 class Scenario(DGeoFlowSubStructure):
     """scenarios/scenario_x.json"""
 
-    ContentVersion: Optional[str] = "2"
-    Id: Optional[str]
-    Label: Optional[str]
-    Notes: Optional[str] = None
-    GeometryId: Optional[str]
-    SoilLayersId: Optional[str]
-    Stages: List[PersistableStage] = []
-    Calculations: List[PersistableCalculation] = []
+    ContentVersion: str | None = "2"
+    Id: str | None = None
+    Label: str | None = None
+    Notes: str | None = None
+    GeometryId: str | None = None
+    SoilLayersId: str | None = None
+    Stages: list[PersistableStage] = []
+    Calculations: list[PersistableCalculation] = []
+
+    id_validator = field_validator("Id", "GeometryId", "SoilLayersId", mode="before")(
+        transform_id_to_str
+    )
 
     @classmethod
     def structure_name(cls) -> str:
@@ -654,16 +710,20 @@ class Scenario(DGeoFlowSubStructure):
 
 class PersistableMeshProperties(DGeoFlowBaseModelStructure):
     LayerId: str
-    Label: Optional[str]
-    ElementSize: Optional[float] = 1
+    Label: str | None = None
+    ElementSize: float | None = 1
+
+    id_validator = field_validator("LayerId", mode="before")(transform_id_to_str)
 
 
 class MeshProperty(DGeoFlowSubStructure):
     """meshproperties/meshproperties_x.json"""
 
-    ContentVersion: Optional[str] = "2"
-    Id: Optional[str]
-    MeshProperties: Optional[List[PersistableMeshProperties]] = []
+    ContentVersion: str | None = "2"
+    Id: str | None = None
+    MeshProperties: list[PersistableMeshProperties] | None = []
+
+    id_validator = field_validator("Id", mode="before")(transform_id_to_str)
 
     @classmethod
     def structure_name(cls) -> str:
@@ -682,7 +742,7 @@ class MeshProperty(DGeoFlowSubStructure):
         self.MeshProperties.append(pmp)
         return pmp
 
-    def get_ids(self, exclude_soil_layer_id: Optional[int]) -> Set[str]:
+    def get_ids(self, exclude_soil_layer_id: int | None) -> set[str]:
         if exclude_soil_layer_id is not None:
             exclude_soil_layer_id = str(exclude_soil_layer_id)
         return {
@@ -695,7 +755,7 @@ class MeshProperty(DGeoFlowSubStructure):
 class DGeoFlowStructure(BaseModelStructure):
     """Highest level DGeoFlow class that should be parsed to and serialized from.
 
-    The List[] items (one for each scenario in the model) will be stored in a subfolder
+    The list[] items (one for each scenario in the model) will be stored in a subfolder
     to multiple json files. Where the first (0) instance
     has no suffix, but the second one has (1 => _1) etc.
 
@@ -703,19 +763,19 @@ class DGeoFlowStructure(BaseModelStructure):
     """
 
     # input part
-    soillayers: List[SoilLayerCollection] = [
+    soillayers: list[SoilLayerCollection] = [
         SoilLayerCollection(Id="14")
     ]  # soillayers/soillayers_x.json
     soils: SoilCollection = SoilCollection()  # soils.json
     soilvisualizations: SoilVisualisation = SoilVisualisation()  # soilvisualizations.json
 
     projectinfo: ProjectInfo = ProjectInfo()  # projectinfo.json
-    geometries: List[Geometry] = [Geometry(Id="1")]  # geometries/geometry_x.json
+    geometries: list[Geometry] = [Geometry(Id="1")]  # geometries/geometry_x.json
 
-    boundary_conditions: List[BoundaryConditionCollection] = [
+    boundary_conditions: list[BoundaryConditionCollection] = [
         BoundaryConditionCollection(Id="15")
     ]  # boundaryconditions/boundaryconditions_x.json
-    scenarios: List[Scenario] = [
+    scenarios: list[Scenario] = [
         Scenario(
             Id="0",
             Label="Scenario 1",
@@ -729,23 +789,20 @@ class DGeoFlowStructure(BaseModelStructure):
             ],
         )
     ]  # scenarios/scenario_x.json
-    mesh_properties: List[MeshProperty] = [
+    mesh_properties: list[MeshProperty] = [
         MeshProperty(Id="16", MeshProperties=[])
     ]  # meshproperties/meshproperties_x.json
 
     # Output parts
-    groundwater_flow_results: List[GroundwaterFlowResult] = []
-    pipe_length_results: List[PipeLengthResult] = []
-    critical_head_results: List[CriticalHeadResult] = []
+    groundwater_flow_results: list[GroundwaterFlowResult] = []
+    pipe_length_results: list[PipeLengthResult] = []
+    critical_head_results: list[CriticalHeadResult] = []
 
-    class Config:
-        arbitrary_types_allowed = True
-        validate_assignment = True
+    model_config = ConfigDict(arbitrary_types_allowed=True, validate_assignment=True)
 
     def get_result_substructure(
         self, calculation_type: CalculationTypeEnum
-    ) -> List[DGeoFlowResult]:
-
+    ) -> list[DGeoFlowResult]:
         result_types_mapping = {
             CalculationTypeEnum.GROUNDWATER_FLOW: self.groundwater_flow_results,
             CalculationTypeEnum.PIPE_LENGTH: self.pipe_length_results,
@@ -754,133 +811,110 @@ class DGeoFlowStructure(BaseModelStructure):
 
         return result_types_mapping[calculation_type]
 
-    @root_validator(skip_on_failure=True, allow_reuse=True)
-    def ensure_validity_foreign_keys(cls, values):
-        stage_count = 0
-        for i, scenario in enumerate(values.get("scenarios")):
+    @model_validator(mode="after")
+    def ensure_validity_foreign_keys(self):
+        def list_has_id(values, id):
+            for entry in values:
+                if entry.Id == id:
+                    return True
+            return False
+
+        for _, scenario in enumerate(self.scenarios):
             for _, stage in enumerate(scenario.Stages):
-                if (
-                    stage.BoundaryConditionCollectionId
-                    != values.get("boundary_conditions")[stage_count].Id
+                if not list_has_id(
+                    self.boundary_conditions, stage.BoundaryConditionCollectionId
                 ):
                     raise ValueError("BoundaryConditionCollectionIds not linked!")
-                stage_count += 1
 
-            if scenario.GeometryId != values.get("geometries")[i].Id:
+            if not list_has_id(self.geometries, scenario.GeometryId):
                 raise ValueError("GeometryIds not linked!")
-            if scenario.SoilLayersId != values.get("soillayers")[i].Id:
+            if not list_has_id(self.soillayers, scenario.SoilLayersId):
                 raise ValueError("SoilLayersIds not linked!")
-        return values
 
-    @property
-    def stage_specific_fields(self):
-        return [
-            "soillayers",
-            "geometries",
-            "boundaryconditions",
-            "meshproperties",
-            "scenarios",
-        ]
-
-    def get_scenario_specific_fields(self, stage=0) -> Tuple[str, DGeoFlowSubStructure]:
-        """Yield stage specific fields for given stage."""
-        for fieldname in self.stage_specific_fields:
-            field = getattr(self, fieldname)
-            if len(field) > stage:
-                yield fieldname, field[stage]
-
-    def renumber_fk_fields(self, instance, mapping: Dict, unique_id: int) -> int:
-        """Replace id (foreign key) fields on instance based on a mapping and unique id."""
-        fk = ForeignKeys()
-        fkfields = fk.class_fields
-
-        def get_correct_key(key, mapping):
-            if key not in mapping:
-                nonlocal unique_id
-                mapping[key] = unique_id
-                unique_id += 1
-            return mapping[key]
-
-        for fkfield in fkfields.get(instance.__class__.__name__, []):
-            value = getattr(instance, fkfield)
-            if isinstance(value, (list, set, tuple)):
-                setattr(
-                    instance,
-                    fkfield,
-                    [get_correct_key(x, mapping) for x in value],
-                )
-            if isinstance(value, (int, float, str)):
-                setattr(instance, fkfield, get_correct_key(value, mapping))
-
-        return unique_id
-
-    def duplicate_scenario(
-        self, current_scenario: int, label: str, notes: str, unique_start_id: int
-    ):
-        """Duplicates an existing scenario.
-        Copies the specific scenario fields for a scenario and renumbers all Ids,
-        taking into account foreign keys by using the same renumbering.
-        """
-
-        old_to_new = {}
-        for fieldname, scenario_field in self.get_scenario_specific_fields(
-            current_scenario
-        ):
-            new_scenario_fields = scenario_field.copy(deep=True)
-
-            # Renumber the upper class
-            unique_start_id = self.renumber_fk_fields(
-                new_scenario_fields, old_to_new, unique_start_id
-            )
-            # Renumber all children
-            for class_instance in children(new_scenario_fields):
-                unique_start_id = self.renumber_fk_fields(
-                    class_instance, old_to_new, unique_start_id
-                )
-
-            # Update the stage with extra supplied fields
-            if fieldname == "stages":
-                new_scenario_fields.Label = label
-                new_scenario_fields.Notes = notes
-
-            getattr(self, fieldname).append(new_scenario_fields)
-
-        return len(self.stages) - 1, unique_start_id
+        return self
 
     def add_default_scenario(
-        self, label: str, notes: str, unique_start_id=500
-    ) -> Tuple[int, int]:
+        self, label: str, notes: str, unique_start_id: int | None = None
+    ) -> tuple[int, int]:
         """Add a new default (empty) scenario to DGeoFlow."""
+        if unique_start_id is None:
+            unique_start_id = self.get_unique_id()
 
+        scenario_id = unique_start_id + 7
         self.soillayers += [SoilLayerCollection(Id=str(unique_start_id + 1))]
         self.mesh_properties += [MeshProperty(Id=str(unique_start_id + 2))]
-        self.geometries += [Geometry(Id=str(unique_start_id + 4))]
+        self.geometries += [Geometry(Id=str(unique_start_id + 3))]
         self.boundary_conditions += [
-            BoundaryConditionCollection(Id=str(unique_start_id + 5))
+            BoundaryConditionCollection(Id=str(unique_start_id + 4))
         ]
 
         self.scenarios += [
             Scenario(
-                Id=str(str(unique_start_id + 7)),
-                Label="Scenario 1",
-                GeometryId=str(unique_start_id + 4),
+                Id=str(scenario_id),
+                Label=label,
+                Notes=notes,
+                GeometryId=str(unique_start_id + 3),
                 SoilLayersId=str(unique_start_id + 1),
-                Calculations=[
-                    PersistableCalculation(
-                        Id=str(unique_start_id + 6), Label="Calculation 1"
-                    )
-                ],
+                Calculations=[PersistableCalculation(Label="Calculation 1")],
                 Stages=[
                     PersistableStage(
-                        Id=str(unique_start_id + 6),
                         Label="Stage 1",
-                        BoundaryConditionCollectionId=str(unique_start_id + 5),
+                        BoundaryConditionCollectionId=str(unique_start_id + 4),
                     )
                 ],
             )
         ]
 
-        return len(self.scenarios) - 1, unique_start_id + 11
+        return len(self.scenarios) - 1, scenario_id
+
+    def add_default_stage(
+        self,
+        scenario_index: int,
+        label: str,
+        notes: str,
+        unique_start_id: int | None = None,
+    ) -> int:
+        """Add a new default (empty) stage to DStability."""
+        if unique_start_id is None:
+            unique_start_id = self.get_unique_id()
+
+        self.boundary_conditions += [
+            BoundaryConditionCollection(Id=str(unique_start_id + 1))
+        ]
+
+        new_stage = PersistableStage(
+            Label=label,
+            Notes=notes,
+            BoundaryConditionCollectionId=str(unique_start_id + 1),
+        )
+
+        scenario = self.scenarios[scenario_index]
+
+        if scenario.Stages is None:
+            scenario.Stages = []
+
+        scenario.Stages.append(new_stage)
+        return len(scenario.Stages) - 1
+
+    def add_default_calculation(
+        self,
+        scenario_index: int,
+        label: str,
+        notes: str,
+    ) -> int:
+        """Add a new default (empty) calculation to DStability."""
+
+        new_calculation = PersistableCalculation(
+            Label=label, Notes=notes, CalculationType=CalculationTypeEnum.GROUNDWATER_FLOW
+        )
+
+        scenario = self.scenarios[scenario_index]
+
+        if scenario.Calculations is None:
+            scenario.Calculations = []
+
+        scenario.Calculations.append(new_calculation)
+        return len(scenario.Calculations) - 1
 
     def get_unique_id(self) -> int:
         """Return unique id that can be used in DGeoFlow.
@@ -944,7 +978,7 @@ class ForeignKeys(DGeoFlowBaseModelStructure):
     as (implicit) foreign keys.
     """
 
-    mapping: Dict[str, Tuple[str, ...]] = {
+    mapping: dict[str, tuple[str, ...]] = {
         "PersistableSoil.Id": (
             "PersistableSoilVisualization.SoilId",
             "PersistableSoilLayer.SoilId",
@@ -963,7 +997,7 @@ class ForeignKeys(DGeoFlowBaseModelStructure):
     }
 
     @property
-    def class_fields(self) -> Dict[str, List[str]]:
+    def class_fields(self) -> dict[str, list[str]]:
         """Return a mapping in the form:
         classname: [fields]
         """
