@@ -1,16 +1,12 @@
 import logging
 from datetime import timedelta
-from operator import attrgetter
 from pathlib import Path
-from subprocess import CompletedProcess, run
-from typing import BinaryIO
-from typing import List, Optional, Type, Union
+from typing import Annotated, BinaryIO
 
-from pydantic import FilePath, validate_arguments
-from pydantic.types import PositiveInt, confloat, conint, constr
+from pydantic import FilePath, StringConstraints
 
 from geolib.geometry import Point
-from geolib.models import BaseDataClass, BaseModel, BaseModelStructure
+from geolib.models.base_model import BaseModel
 from geolib.models.dsettlement.internal_soil import SoilInternal
 from geolib.models.dsettlement.loads import (
     CircularLoad,
@@ -23,30 +19,25 @@ from geolib.models.dsettlement.probabilistic_calculation_types import (
     ProbabilisticCalculationType,
 )
 from geolib.models.dsettlement.serializer import DSettlementInputSerializer
-from geolib.models.meta import CONSOLE_RUN_BATCH_FLAG, MetaData
+from geolib.models.meta import CONSOLE_RUN_BATCH_FLAG
 from geolib.soils import DistributionType
 from geolib.soils import Soil as Soil_Input
 
 from .drains import VerticalDrain
 from .dsettlement_parserprovider import DSettlementParserProvider
 from .internal import (
-    Boundary,
     CalculationOptions,
     ConsolidationModel,
-    Curve,
     Dimension,
     DSeriePoint,
     DSettlementOutputStructure,
     DSettlementStructure,
     Layer,
-    Layers,
     Model,
     NonUniformLoad,
     NonUniformLoads,
     OtherLoads,
-    PiezoLines,
     PointForLoad,
-    Points,
     ResidualTimes,
     Results,
     SoilModel,
@@ -67,31 +58,35 @@ class DSettlementModel(BaseModel):
     \*.sli files, read \*.sld and \*.err files.
     """
 
-    datastructure: Union[
-        DSettlementStructure, DSettlementOutputStructure
-    ] = DSettlementStructure()
+    datastructure: DSettlementStructure | DSettlementOutputStructure = (
+        DSettlementStructure()
+    )
 
     @property
-    def parser_provider_type(self) -> Type[DSettlementParserProvider]:
+    def parser_provider_type(self) -> type[DSettlementParserProvider]:
         return DSettlementParserProvider
 
     @property
-    def console_path(self) -> Path:
-        return Path("DSettlementConsole/DSettlementConsole.exe")
+    def default_console_path(self) -> Path:
+        return Path("DSettlement/DSettlement.exe")
 
     @property
-    def console_flags(self) -> List[str]:
+    def custom_console_path(self) -> Path:
+        return self.get_meta_property("dsettlement_console_path")
+
+    @property
+    def console_flags(self) -> list[str]:
         return [CONSOLE_RUN_BATCH_FLAG]
 
-    def serialize(self, filename: Union[FilePath, BinaryIO]):
+    def serialize(self, filename: FilePath | BinaryIO):
         """
         Serialize and pre-process
         Args:
             filename:
         """
-        self.datastructure.geometry_data.pre_process()
+        self.datastructure.input_data.geometry_data.pre_process()
 
-        serializer = DSettlementInputSerializer(ds=self.datastructure.dict())
+        serializer = DSettlementInputSerializer(ds=self.datastructure.input_data.dict())
         serializer.write(filename)
 
         if isinstance(filename, Path):
@@ -100,7 +95,7 @@ class DSettlementModel(BaseModel):
     def add_soil(self, soil_input: Soil_Input) -> None:
         """Soil is converted in the internal structure and added in soil_collection."""
         soil_new = soil_input._to_dsettlement()
-        self.datastructure.soil_collection.add_soil_if_unique(soil_new)
+        self.datastructure.input_data.soil_collection.add_soil_if_unique(soil_new)
 
     # 1.2.3 Models
     def set_model(
@@ -114,7 +109,6 @@ class DSettlementModel(BaseModel):
         is_probabilistic: bool,
         is_horizontal_displacements: bool,
         is_secondary_swelling: bool,
-        is_waspan: bool,
     ):
         """
         Sets the D-settlement Model. Initializes CalculationOptions and Model if the type is str
@@ -129,20 +123,19 @@ class DSettlementModel(BaseModel):
             is_probabilistic (bool): true if probabilistic calculation should be made
             is_horizontal_displacements (bool): true if horizontal displacements should be calculated
             is_secondary_swelling (bool): true if secondary swelling is present
-            is_waspan (bool): true if waspan
 
         Returns:
             Model
         """
-        if isinstance(self.datastructure.calculation_options, str):
+        if isinstance(self.datastructure.input_data.calculation_options, str):
             logger.warning("Calculation options are overwritten")
-            self.datastructure.calculation_options = CalculationOptions()
+            self.datastructure.input_data.calculation_options = CalculationOptions()
 
-        if isinstance(self.datastructure.model, str):
+        if isinstance(self.datastructure.input_data.model, str):
             logger.warning("Model options are overwritten")
-            self.datastructure.model = Model()
+            self.datastructure.input_data.model = Model()
 
-        model_options = self.datastructure.model
+        model_options = self.datastructure.input_data.model
 
         model_options.dimension = (
             Dimension.TWO_D if is_two_dimensional else Dimension.ONE_D
@@ -155,7 +148,6 @@ class DSettlementModel(BaseModel):
         model_options.is_probabilistic = is_probabilistic
         model_options.is_horizontal_displacements = is_horizontal_displacements
         model_options.is_secondary_swelling = is_secondary_swelling
-        model_options.is_waspan = is_waspan
 
         return model_options
 
@@ -166,7 +158,7 @@ class DSettlementModel(BaseModel):
         Args:
             precon_pressure_within_layer (PreconPressureWithinLayer): type of preconsolidation pressure within the layer
             is_imaginary_surface (bool): true if imaginary surface
-            imaginary_surface_layer (PositivInt): index of layer
+            imaginary_surface_layer (PositivInt): index of the layer whose top acts as the imaginary surface
             is_submerging (bool): true if submerging
             use_end_time_for_fit (bool): true if end time should be used for fit
             is_maintain_profile (bool): true if profile should be maintained
@@ -197,45 +189,65 @@ class DSettlementModel(BaseModel):
         Returns:
             calculation options
         """
-        if isinstance(self.datastructure.calculation_options, str):
+        if isinstance(self.datastructure.input_data.calculation_options, str):
             logger.warning("Calculation options are overwritten")
-            self.datastructure.calculation_options = CalculationOptions()
+            self.datastructure.input_data.calculation_options = CalculationOptions()
 
-        if isinstance(self.datastructure.model, str):
+        if isinstance(self.datastructure.input_data.model, str):
             logger.warning("Model options are overwritten")
-            self.datastructure.model = Model()
+            self.datastructure.input_data.model = Model()
 
-        calculation_options = self.datastructure.calculation_options.dict()
+        calculation_options = self.datastructure.input_data.calculation_options.dict()
         calculation_options.update(**kwargs)
-        self.datastructure.calculation_options = CalculationOptions.set_options(
-            **calculation_options
+        self.datastructure.input_data.calculation_options = (
+            CalculationOptions.set_imaginary_surface_options(**calculation_options)
         )
 
+        """Check that the given layer index refers to an existing index layer"""
+        options = self.datastructure.input_data.calculation_options
+        if options.is_imaginary_surface and (
+            options.imaginary_surface_layer < 1
+            or options.imaginary_surface_layer > self.layers.layers.__len__()
+        ):
+            raise ValueError(
+                "The index of imaginary_surface_layer refers to a nonexistent layer index."
+            )
+
         return calculation_options
 
     @property
-    def accuracy(self):
-        return self.datastructure.geometry_data.accuracy
+    def input(self):
+        return self.datastructure.input_data
 
     @property
     def curves(self):
-        return self.datastructure.geometry_data.curves
+        return self.datastructure.input_data.geometry_data.curves
 
     @property
     def boundaries(self):
-        return self.datastructure.geometry_data.boundaries
+        return self.datastructure.input_data.geometry_data.boundaries
 
     @property
     def use_probabilistic_defaults_boundaries(self):
-        return self.datastructure.geometry_data.use_probabilistic_defaults_boundaries
+        return (
+            self.datastructure.input_data.geometry_data.use_probabilistic_defaults_boundaries
+        )
 
     @property
     def stdv_boundaries(self):
-        return self.datastructure.geometry_data.stdv_boundaries
+        return self.datastructure.input_data.geometry_data.stdv_boundaries
 
     @property
     def distribution_boundaries(self):
-        return self.datastructure.geometry_data.distribution_boundaries
+        return self.datastructure.input_data.geometry_data.distribution_boundaries
+
+    @property
+    def fit_options(self):
+        return self.datastructure.input_data.fit_options
+
+    @property
+    def fit_calculation(self):
+        return self.datastructure.input_data.fit_calculation
 
     def set_probabilistic_data(
         self,
@@ -272,9 +284,11 @@ class DSettlementModel(BaseModel):
             is_reliability_calculation : set to True if a probabilistic calculation should be performed.
 
         """
-        self.datastructure.check_x_in_vertical(point_of_vertical=point_of_vertical)
-        self.datastructure.probabilistic_data = (
-            self.datastructure.probabilistic_data.set_probabilistic_data(
+        self.datastructure.input_data.check_x_in_vertical(
+            point_of_vertical=point_of_vertical
+        )
+        self.datastructure.input_data.probabilistic_data = (
+            self.datastructure.input_data.probabilistic_data.set_probabilistic_data(
                 point_of_vertical=point_of_vertical,
                 residual_settlement=residual_settlement,
                 maximum_number_of_samples=maximum_number_of_samples,
@@ -288,7 +302,7 @@ class DSettlementModel(BaseModel):
     # To create multiple layers
     def add_boundary(
         self,
-        points: List[Point],
+        points: list[Point],
         use_probabilistic_defaults=True,
         stdv=0,
         distribution_boundaries=DistributionType.Undefined,
@@ -296,7 +310,7 @@ class DSettlementModel(BaseModel):
         """Add boundary to model."""
         # Divide points into curves and boundary
         # Check point uniqueness
-        tolerance = self.accuracy.accuracy
+        tolerance = 0.001
         points = [
             self.points.add_point_if_unique(
                 DSeriePoint.from_point(point), tolerance=tolerance
@@ -317,13 +331,13 @@ class DSettlementModel(BaseModel):
     @property
     def points(self):
         """Enables easy access to the points in the internal dict-like datastructure. Also enables edit/delete for individual points."""
-        return self.datastructure.geometry_data.points
+        return self.datastructure.input_data.geometry_data.points
 
     @property
     def headlines(self):
-        return self.datastructure.geometry_data.piezo_lines
+        return self.datastructure.input_data.geometry_data.piezo_lines
 
-    def add_head_line(self, points: List[Point], is_phreatic=False) -> int:
+    def add_head_line(self, points: list[Point], is_phreatic=False) -> int:
         """Add head line to model."""
         # New points have to be created, whether points at the same location exist or not
         # This means that new points from geometry will re-use head line points,
@@ -336,12 +350,14 @@ class DSettlementModel(BaseModel):
 
         piezo_line = self.headlines.create_piezoline(curves)
         if is_phreatic:
-            self.datastructure.geometry_data.phreatic_line.phreatic_line = piezo_line.id
+            self.datastructure.input_data.geometry_data.phreatic_line.phreatic_line = (
+                piezo_line.id
+            )
         return piezo_line.id
 
     @property
     def layers(self):
-        return self.datastructure.geometry_data.layers
+        return self.datastructure.input_data.geometry_data.layers
 
     def add_layer(
         self,
@@ -382,36 +398,36 @@ class DSettlementModel(BaseModel):
     @property
     def other_loads(self):
         """Enables easy access to the other loads in the internal dict-like datastructure."""
-        return self.datastructure.other_loads
+        return self.datastructure.input_data.other_loads
 
     def add_other_load(
         self,
-        name: constr(min_length=1, max_length=25),
+        name: Annotated[str, StringConstraints(min_length=1, max_length=25)],
         time: timedelta,
         point: Point,
-        other_load: Union[
-            TrapeziformLoad, RectangularLoad, CircularLoad, TankLoad, UniformLoad
-        ],
+        other_load: (
+            TrapeziformLoad | RectangularLoad | CircularLoad | TankLoad | UniformLoad
+        ),
     ) -> None:
         internal_other_load = other_load._to_internal(time, point)
         if isinstance(self.other_loads, str):
             logger.warning("Replacing unparsed OtherLoads!")
-            self.datastructure.other_loads = OtherLoads()
+            self.datastructure.input_data.other_loads = OtherLoads()
         self.other_loads.add_load(name, internal_other_load)
 
     @property
     def non_uniform_loads(self):
         """Enables easy access to the non-uniform loads in the internal dict-like datastructure."""
-        return self.datastructure.non__uniform_loads
+        return self.datastructure.input_data.non__uniform_loads
 
     def add_non_uniform_load(
         self,
-        name: constr(min_length=1, max_length=25),
-        points: List[Point],
+        name: Annotated[str, StringConstraints(min_length=1, max_length=25)],
+        points: list[Point],
         time_start: timedelta,
         gamma_dry: float,
         gamma_wet: float,
-        time_end: Optional[timedelta] = None,
+        time_end: timedelta | None = None,
     ):
         """Create non uniform load.
 
@@ -438,7 +454,7 @@ class DSettlementModel(BaseModel):
 
         if isinstance(self.non_uniform_loads, str):
             logger.warning("Replacing unparsed NonUniformLoads!")
-            self.datastructure.non__uniform_loads = NonUniformLoads()
+            self.datastructure.input_data.non__uniform_loads = NonUniformLoads()
         self.non_uniform_loads.add_load(name, non_uniform_load)
 
     def add_water_load(self, name: str, time: timedelta, phreatic_line_id: int):
@@ -446,15 +462,15 @@ class DSettlementModel(BaseModel):
 
         Edit the head lines for each layer with `create layer`.
         """
-        if isinstance(self.datastructure.water_loads, str):
+        if isinstance(self.datastructure.input_data.water_loads, str):
             logger.warning("Replacing unparsed [WATER LOADS]!")
-            self.datastructure.water_loads = WaterLoads()
-        headlines = self.datastructure.get_headlines_for_layers()
-        self.datastructure.water_loads.add_waterload(
+            self.datastructure.input_data.water_loads = WaterLoads()
+        headlines = self.datastructure.input_data.get_headlines_for_layers()
+        self.datastructure.input_data.water_loads.add_waterload(
             name, time.days, phreatic_line_id, headlines
         )
 
-    def set_calculation_times(self, time_steps: List[timedelta]):
+    def set_calculation_times(self, time_steps: list[timedelta]):
         """(Re)set calculation time(s).
 
         Sets a list of calculation times, sorted from low to high with a minimum of 0.
@@ -469,9 +485,9 @@ class DSettlementModel(BaseModel):
         residual_times = ResidualTimes(
             time_steps=[timestep.days for timestep in time_steps]
         )
-        self.datastructure.residual_times = residual_times
+        self.datastructure.input_data.residual_times = residual_times
 
-    def set_verticals(self, locations: List[Point]) -> None:
+    def set_verticals(self, locations: list[Point]) -> None:
         """
         Set calculation verticals in geometry.
         X and Y coordinates should be defined for each vertical.
@@ -481,11 +497,11 @@ class DSettlementModel(BaseModel):
         """
         points = [DSeriePoint.from_point(point) for point in locations]
         verticals = Verticals(locations=points)
-        self.datastructure.verticals = verticals
+        self.datastructure.input_data.verticals = verticals
 
     def set_vertical_drain(self, verticaldrain: VerticalDrain):
-        if self.datastructure.model.is_vertical_drains:
-            self.datastructure.vertical_drain = verticaldrain._to_internal()
+        if self.datastructure.input_data.model.is_vertical_drains:
+            self.datastructure.input_data.vertical_drain = verticaldrain._to_internal()
         else:
             raise ValueError(
                 "If you wish to add a vertical drain then value is_vertical_drains for the model should be True"
