@@ -3,18 +3,19 @@ from enum import Enum, IntEnum
 from inspect import cleandoc
 from math import isclose
 from operator import attrgetter
-from typing import Any, Dict, List, Optional, Tuple, Type, Union
 
-from pydantic.types import PositiveInt, confloat, conint, conlist, constr
+from pydantic import Field, StringConstraints
+from pydantic.types import PositiveInt
+from typing_extensions import Annotated
 
 from geolib.geometry.one import Point
 from geolib.models import BaseDataClass
-from geolib.models.base_model_structure import BaseModelStructure
 from geolib.models.dseries_parser import (
     DSerieListStructure,
     DSerieMatrixStructure,
     DSerieOldTableStructure,
     DSeriesInlineMappedProperties,
+    DSeriesInlineReversedProperties,
     DSeriesMatrixTreeStructureCollection,
     DSeriesNoParseSubStructure,
     DSeriesRepeatedGroupedProperties,
@@ -36,8 +37,7 @@ from geolib.models.dsettlement.probabilistic_calculation_types import (
 )
 from geolib.models.internal import Bool
 from geolib.models.utils import get_required_class_field
-from geolib.soils import DistributionType, HorizontalBehaviourType, Soil
-from geolib.soils import StorageTypes as StorageTypes_external
+from geolib.soils import DistributionType
 from geolib.utils import make_newline_validator
 
 from .drain_types import DrainGridType, DrainSchedule, DrainType
@@ -66,7 +66,7 @@ class DSeriePoint(DSeriesTreeStructure):
     tolerance: float = TOLERANCE
 
     @classmethod
-    def get_structure_required_fields(cls) -> List[Tuple[str, Type]]:
+    def get_structure_required_fields(cls) -> list[tuple[str, type]]:
         point_required_field_names = [
             required_field[0] for required_field in get_required_class_field(cls)
         ]
@@ -91,7 +91,7 @@ class DSeriePoint(DSeriesTreeStructure):
 
 
 class SoilCollection(DSeriesStructureCollection):
-    soil: List[SoilInternal] = []
+    soil: list[SoilInternal] = []
 
     def add_soil_if_unique(self, soil, tolerance=TOLERANCE) -> None:
         for added_soil in self.soil:
@@ -101,15 +101,15 @@ class SoilCollection(DSeriesStructureCollection):
 
 
 class Version(DSerieVersion):
-    soil: int = 1005
-    geometry: int = 1000
-    d__settlement: int = 1007
+    soil: int = 1011
+    geometry: int = 1002
+    d__settlement: int = 1011
 
 
 class Points(DSeriesMatrixTreeStructureCollection):
     """Representation of [POINTS] group."""
 
-    points: List[DSeriePoint] = []
+    points: list[DSeriePoint] = []
 
     def add_point_if_unique(self, point: DSeriePoint, tolerance=TOLERANCE) -> DSeriePoint:
         if point in self.points:
@@ -135,7 +135,7 @@ class Curve(DSeriesTreeStructure):
     """Curve is a Line consisting of two points (by reference)."""
 
     id: PositiveInt = 1
-    points: conlist(int, min_items=2, max_items=2)
+    points: Annotated[list[int], Field(min_length=2, max_length=2)]
 
     def __eq__(self, other: object) -> bool:
         """
@@ -156,7 +156,7 @@ class Curve(DSeriesTreeStructure):
 class Curves(DSeriesTreeStructureCollection):
     """Representation of [CURVES] group."""
 
-    curves: List[Curve] = []
+    curves: list[Curve] = []
 
     def create_curve(self, a: DSeriePoint, b: DSeriePoint):
         assert a.id != b.id
@@ -174,8 +174,7 @@ class Curves(DSeriesTreeStructureCollection):
 
         return curve
 
-    def create_curves(self, sorted_points: List[DSeriePoint]) -> List[Curve]:
-
+    def create_curves(self, sorted_points: list[DSeriePoint]) -> list[Curve]:
         new_curves = [
             self.create_curve(sorted_points[i], sorted_points[i + 1])
             for i in range(len(sorted_points) - 1)
@@ -190,8 +189,8 @@ class Curves(DSeriesTreeStructureCollection):
 
 
 class Boundary(DSeriesTreeStructure):
-    id: conint(ge=0) = 0
-    curves: List[int] = []
+    id: Annotated[int, Field(ge=0)] = 0
+    curves: list[int] = []
 
     def __eq__(self, other: object) -> bool:
         """
@@ -212,9 +211,9 @@ class Boundary(DSeriesTreeStructure):
 class Boundaries(DSeriesTreeStructureCollection):
     """Representation of [BOUNDARIES] group."""
 
-    boundaries: List[Boundary] = []
+    boundaries: list[Boundary] = []
 
-    def create_boundary(self, curves: List[Curve]) -> Boundary:
+    def create_boundary(self, curves: list[Curve]) -> Boundary:
         boundary = Boundary(curves=[curve.id for curve in curves])
 
         # Return the id of existing one
@@ -241,8 +240,8 @@ class Boundaries(DSeriesTreeStructureCollection):
 class Layer(DSeriesTreeStructure):
     id: PositiveInt = 1
     material: str = ""  # reference to soil name
-    piezo_top: conint(ge=0, le=99) = 0  # reference to head line
-    piezo_bottom: conint(ge=0, le=99) = 0  # reference to head line
+    piezo_top: Annotated[int, Field(ge=0, le=99)] = 0  # reference to head line
+    piezo_bottom: Annotated[int, Field(ge=0, le=99)] = 0  # reference to head line
     boundary_top: int  # reference to boundary
     boundary_bottom: int  # reference to boundary
 
@@ -268,10 +267,9 @@ class Layer(DSeriesTreeStructure):
 class Layers(DSeriesTreeStructureCollection):
     """Representation of [LAYERS] group."""
 
-    layers: List[Layer] = []
+    layers: list[Layer] = []
 
     def add_layer(self, layer: Layer):
-
         if layer in self.layers:
             existing_layer = self.layers[self.layers.index(layer)]
             logger.warning(
@@ -298,7 +296,7 @@ class Layers(DSeriesTreeStructureCollection):
 
 class PiezoLine(DSeriesTreeStructure):
     id: PositiveInt = 1
-    curves: List[int] = []
+    curves: list[int] = []
 
     def __eq__(self, other: object):
         if isinstance(other, PiezoLine):
@@ -309,9 +307,9 @@ class PiezoLine(DSeriesTreeStructure):
 class PiezoLines(DSeriesTreeStructureCollection):
     """Representation of [PIEZO LINES] group."""
 
-    piezolines: List[PiezoLine] = []
+    piezolines: list[PiezoLine] = []
 
-    def create_piezoline(self, curves: List[Curve]) -> PiezoLine:
+    def create_piezoline(self, curves: list[Curve]) -> PiezoLine:
         piezoline = PiezoLine(curves=[curve.id for curve in curves])
 
         if piezoline in self.piezolines:
@@ -334,7 +332,7 @@ class PiezoLines(DSeriesTreeStructureCollection):
 
 
 class UseProbabilisticDefaultsBoundaries(DSerieListStructure):
-    useprobabilisticdefaultsboundaries: List[Bool] = []
+    useprobabilisticdefaultsboundaries: list[Bool] = []
 
     def append_use_probabilistic_defaults_boundary(
         self, use_probabilistic_boundary: bool
@@ -345,14 +343,14 @@ class UseProbabilisticDefaultsBoundaries(DSerieListStructure):
 
 
 class StdvBoundaries(DSerieListStructure):
-    stdvboundaries: List[float] = []
+    stdvboundaries: list[float] = []
 
     def append_stdv_boundary(self, stdv_boundary: float):
         self.stdvboundaries.append(stdv_boundary)
 
 
 class DistributionBoundaries(DSerieListStructure):
-    distributionboundaries: List[DistributionType] = []
+    distributionboundaries: list[DistributionType] = []
 
     def append_distribution_boundary(self, distribution_boundary: DistributionType):
         if (distribution_boundary is DistributionType.Normal) or (
@@ -365,18 +363,13 @@ class DistributionBoundaries(DSerieListStructure):
             )
 
 
-class Accuracy(DSeriesUnmappedNameProperties):
-    accuracy: confloat(ge=1e-10) = 1e-3
-
-
 class PhreaticLine(DSeriesUnmappedNameProperties):
-    phreatic_line: conint(ge=0, lt=99) = 0
+    phreatic_line: Annotated[int, Field(ge=0, lt=99)] = 0
 
 
 class GeometryData(DSeriesStructure):
     """Representation of [GEOMETRY DATA] group."""
 
-    accuracy: Accuracy = Accuracy()
     points: Points = Points()
     curves: Curves = Curves()
     boundaries: Boundaries = Boundaries()
@@ -387,16 +380,7 @@ class GeometryData(DSeriesStructure):
     distribution_boundaries: DistributionBoundaries = DistributionBoundaries()
     piezo_lines: PiezoLines = PiezoLines()
     phreatic_line: PhreaticLine = PhreaticLine()
-    world_co__ordinates: str = cleandoc(
-        """
-          0.000 - X world 1 -
-          0.000 - Y world 1 -
-          0.000 - X world 2 -
-          0.000 - Y world 2 -
-          """
-    )
     layers: Layers = Layers()
-    layerloads: str = ""
 
     def boundary_area_above_horizontal(self, boundary: Boundary, y: float = 0.0) -> float:
         """Area above horizontal line defined by y-coordinate."""
@@ -454,22 +438,22 @@ class GeometryData(DSeriesStructure):
         self.sort_boundaries()
         self.sort_probabilistic_list_based_on_new_indexes()
 
-    def create_list_of_indexes(self) -> List:
+    def create_list_of_indexes(self) -> list:
         return [boundary.id for boundary in self.boundaries.boundaries]
 
-    def sort_based_on_new_indexes(self, new_indexes: List, unsorted_list: List) -> List:
+    def sort_based_on_new_indexes(self, new_indexes: list, unsorted_list: list) -> list:
         return [unsorted_list[i] for i in new_indexes]
 
-    def get_point(self, point_id: int) -> Optional[DSeriePoint]:
+    def get_point(self, point_id: int) -> DSeriePoint | None:
         return self.points[point_id]
 
-    def get_curve(self, curve_id: int) -> Optional[Curve]:
+    def get_curve(self, curve_id: int) -> Curve | None:
         return self.curves[curve_id]
 
-    def get_boundary(self, boundary_id: int) -> Optional[Boundary]:
+    def get_boundary(self, boundary_id: int) -> Boundary | None:
         return self.boundaries[boundary_id]
 
-    def get_layer(self, layer_id: int) -> Optional[Layer]:
+    def get_layer(self, layer_id: int) -> Layer | None:
         return self.layers[layer_id]
 
 
@@ -491,17 +475,21 @@ class NonUniformLoad(BaseDataClass):
     gammawet: float = 10
     temporary: Bool = False
     endtime: int = 0
-    points: List[PointForLoad]
+    points: list[PointForLoad]
 
 
 class NonUniformLoads(DSeriesNoParseSubStructure):
     """Representation of [NON-UNIFORM LOADS] group."""
 
-    loads: Dict[constr(min_length=1, max_length=25), NonUniformLoad] = {}
+    loads: dict[
+        Annotated[str, StringConstraints(min_length=1, max_length=25)], NonUniformLoad
+    ] = {}
 
     def add_load(
-        self, name: constr(min_length=1, max_length=25), load: NonUniformLoad
-    ) -> Optional[ValueError]:
+        self,
+        name: Annotated[str, StringConstraints(min_length=1, max_length=25)],
+        load: NonUniformLoad,
+    ) -> ValueError | None:
         if name in self.loads:
             raise ValueError(f"Load with name '{name}' already exists.")
         else:
@@ -514,16 +502,16 @@ class WaterLoad(BaseDataClass):
     name: str = ""
     time: int = 0
     phreatic_line: int = 1
-    headlines: List[List[int]] = [[]]
+    headlines: list[list[int]] = [[]]
 
 
 class WaterLoads(DSeriesNoParseSubStructure):
     """Representation of [WATER LOADS] group."""
 
-    waterloads: List[WaterLoad] = []
+    waterloads: list[WaterLoad] = []
 
     def add_waterload(
-        self, name: str, time: int, phreatic_line: int, headlines: List[List[int]]
+        self, name: str, time: int, phreatic_line: int, headlines: list[list[int]]
     ):
         self.waterloads.append(
             WaterLoad(
@@ -535,15 +523,13 @@ class WaterLoads(DSeriesNoParseSubStructure):
 class ResidualTimes(DSeriesNoParseSubStructure):
     """Representation of [RESIDUAL TIMES] group."""
 
-    time_steps: List[conint(ge=0)] = []
+    time_steps: list[Annotated[int, Field(ge=0)]] = []
 
 
 class Verticals(DSeriesNoParseSubStructure):
     """Representation of [VERTICALS] group."""
 
-    # total mesh is default value that is written in sli file but not read
-    total_mesh: int = 100
-    locations: List[DSeriePoint] = []
+    locations: list[DSeriePoint] = []
 
 
 class TypeOtherLoads(IntEnum):
@@ -604,21 +590,25 @@ class LoadValuesTank(BaseDataClass):
 class OtherLoad(BaseDataClass):
     load_type: TypeOtherLoads
     time: int = 0
-    load_values_trapeziform: Optional[LoadValuesTrapeziform]
-    load_values_circular: Optional[LoadValuesCircular]
-    load_values_rectangular: Optional[LoadValuesRectangular]
-    load_values_uniform: Optional[LoadValuesUniform]
-    load_values_tank: Optional[LoadValuesTank]
+    load_values_trapeziform: LoadValuesTrapeziform | None = None
+    load_values_circular: LoadValuesCircular | None = None
+    load_values_rectangular: LoadValuesRectangular | None = None
+    load_values_uniform: LoadValuesUniform | None = None
+    load_values_tank: LoadValuesTank | None = None
 
 
 class OtherLoads(DSeriesNoParseSubStructure):
     """Representation of [OTHER LOADS] group."""
 
-    loads: Dict[constr(min_length=1, max_length=25), OtherLoad] = {}
+    loads: dict[
+        Annotated[str, StringConstraints(min_length=1, max_length=25)], OtherLoad
+    ] = {}
 
     def add_load(
-        self, name: constr(min_length=1, max_length=25), load: OtherLoad
-    ) -> Optional[ValueError]:
+        self,
+        name: Annotated[str, StringConstraints(min_length=1, max_length=25)],
+        load: OtherLoad,
+    ) -> ValueError | None:
         if name in self.loads:
             raise ValueError(f"Load with name '{name}' already exists.")
         else:
@@ -626,28 +616,28 @@ class OtherLoads(DSeriesNoParseSubStructure):
             return None
 
 
-class Dimension(Enum):
+class Dimension(IntEnum):
     ONE_D = 0
     TWO_D = 1
 
 
-class ConsolidationModel(Enum):
+class ConsolidationModel(IntEnum):
     DARCY = 0
     TERZAGHI = 1
 
 
-class SoilModel(Enum):
+class SoilModel(IntEnum):
     NEN_KOPPEJAN = 0
     NEN_BJERRUM = 1
     ISOTACHE = 2
 
 
-class StrainType(Enum):
+class StrainType(IntEnum):
     LINEAR = 0
     NATURAL = 1
 
 
-class Model(DSeriesNoParseSubStructure):
+class Model(DSeriesInlineReversedProperties):
     dimension: Dimension = Dimension.TWO_D
     consolidation_model: ConsolidationModel = ConsolidationModel.DARCY
     soil_model: SoilModel = SoilModel.NEN_KOPPEJAN
@@ -656,11 +646,11 @@ class Model(DSeriesNoParseSubStructure):
     is_fit_for_settlement_plate: Bool = Bool.FALSE
     is_probabilistic: Bool = Bool.FALSE
     is_horizontal_displacements: Bool = Bool.FALSE
+    # Secondary Swelling is only available in Evaluation version (Deltares only)
     is_secondary_swelling: Bool = Bool.FALSE
-    is_waspan: Bool = Bool.FALSE
 
 
-class PreconPressureWithinLayer(Enum):
+class PreconPressureWithinLayer(IntEnum):
     CONSTANT_NO_CORRECTION = 0
     CONSTANT_CORRECTION_T0 = 1
     CONSTANT_CORRECTION_ALL_T = 2
@@ -698,14 +688,14 @@ class CalculationOptions(DSeriesNoParseSubStructure):
         PreconPressureWithinLayer.CONSTANT_NO_CORRECTION
     )
     is_imaginary_surface: Bool = Bool.FALSE
-    imaginary_surface_layer: Optional[PositiveInt]
+    imaginary_surface_layer: PositiveInt | None = None
     is_submerging: Bool = Bool.FALSE
     use_end_time_for_fit: Bool = Bool.FALSE
     is_maintain_profile: Bool = Bool.FALSE
     maintain_profile_material_name: str = "Superelevation"
-    maintain_profile_time: conint(ge=0, le=100000) = 0
-    maintain_profile_gamma_dry: confloat(ge=-100, le=100) = 10
-    maintain_profile_gamma_wet: confloat(ge=-100, le=100) = 10
+    maintain_profile_time: Annotated[int, Field(ge=0, le=100000)] = 0
+    maintain_profile_gamma_dry: Annotated[float, Field(ge=-100, le=100)] = 10
+    maintain_profile_gamma_wet: Annotated[float, Field(ge=-100, le=100)] = 10
     dispersion_conditions_layer_boundaries_top: DispersionConditionLayerBoundary = (
         DispersionConditionLayerBoundary.DRAINED
     )
@@ -714,16 +704,18 @@ class CalculationOptions(DSeriesNoParseSubStructure):
     )
     stress_distribution_soil: StressDistributionSoil = StressDistributionSoil.BUISMAN
     stress_distribution_loads: StressDistributionLoads = StressDistributionLoads.SIMULATE
-    iteration_stop_criteria_submerging: confloat(ge=0.0, le=1.0) = 0.0
-    iteration_stop_criteria_submerging_layer_height: confloat(ge=0, le=99.999) = 0
-    maximum_iteration_steps_for_submerging: conint(ge=1, le=100) = 1
-    iteration_stop_criteria_desired_profile: confloat(ge=0, le=1) = 0.1
-    load_column_width_imaginary_surface: confloat(ge=0.05, le=10000) = 1
-    load_column_width_non_uniform_loads: confloat(ge=0.05, le=10000) = 1
-    load_column_width_trapeziform_loads: confloat(ge=0.05, le=10000) = 1
-    end_of_consolidation: conint(ge=1, le=100000) = 100000
-    number_of_subtime_steps: conint(ge=1, le=100) = 2
-    reference_time: confloat(ge=0.001, le=1000000) = 1
+    iteration_stop_criteria_submerging: Annotated[float, Field(ge=0.0, le=1.0)] = 0.0
+    iteration_stop_criteria_submerging_layer_height: Annotated[
+        float, Field(ge=0, le=99.999)
+    ] = 0
+    maximum_iteration_steps_for_submerging: Annotated[int, Field(ge=1, le=100)] = 1
+    iteration_stop_criteria_desired_profile: Annotated[float, Field(ge=0, le=1)] = 0.1
+    load_column_width_imaginary_surface: Annotated[float, Field(ge=0.05, le=10000)] = 1
+    load_column_width_non_uniform_loads: Annotated[float, Field(ge=0.05, le=10000)] = 1
+    load_column_width_trapeziform_loads: Annotated[float, Field(ge=0.05, le=10000)] = 1
+    end_of_consolidation: Annotated[int, Field(ge=1, le=100000)] = 100000
+    number_of_subtime_steps: Annotated[int, Field(ge=1, le=100)] = 2
+    reference_time: Annotated[float, Field(ge=0.001, le=1000000)] = 1
     dissipation: Bool = Bool.FALSE
     x_coord_dissipation: float = 0.0
     use_fit_factors: Bool = Bool.FALSE
@@ -731,7 +723,7 @@ class CalculationOptions(DSeriesNoParseSubStructure):
     is_predict_settlements_omitting_additional_load_steps: Bool = Bool.FALSE
 
     @classmethod
-    def set_options(cls, **kwargs):
+    def set_imaginary_surface_options(cls, **kwargs):
         cls_instance = cls(**kwargs)
         if cls_instance.is_imaginary_surface == Bool.FALSE:
             cls_instance.imaginary_surface_layer = None
@@ -743,31 +735,33 @@ class CalculationOptions(DSeriesNoParseSubStructure):
 class VerticalDrain(DSeriesNoParseSubStructure):
     # geometry of drain
     drain_type: DrainType = DrainType.STRIP
-    range_from: confloat(ge=-10000000.000, le=10000000.000) = 0
-    range_to: confloat(ge=-10000000.000, le=10000000.000) = 0
-    bottom_position: confloat(ge=-10000000.000, le=10000000.000) = 0
-    center_to_center: confloat(ge=0.001, le=1000) = 3
-    width: confloat(ge=0.001, le=1000) = 0.1
-    diameter: confloat(ge=0.001, le=1000) = 0.1
-    thickness: confloat(ge=0.001, le=1000) = 0.003
+    range_from: Annotated[float, Field(ge=-10000000.000, le=10000000.000)] = 0
+    range_to: Annotated[float, Field(ge=-10000000.000, le=10000000.000)] = 0
+    bottom_position: Annotated[float, Field(ge=-10000000.000, le=10000000.000)] = 0
+    center_to_center: Annotated[float, Field(ge=0.001, le=1000)] = 3
+    width: Annotated[float, Field(ge=0.001, le=1000)] = 0.1
+    diameter: Annotated[float, Field(ge=0.001, le=1000)] = 0.1
+    thickness: Annotated[float, Field(ge=0.001, le=1000)] = 0.003
     grid: DrainGridType = DrainGridType.UNDERDETERMINED
     # schedule
     schedule_type: DrainSchedule = DrainSchedule.OFF
-    begin_time: confloat(ge=0, le=100000) = 0
-    end_time: confloat(ge=0, le=100000) = 0
-    under_pressure_for_strips_and_columns: confloat(ge=0, le=100000) = 35
-    under_pressure_for_sand_wall: confloat(ge=0, le=100000) = 35
-    start_of_drainage: confloat(ge=0, le=100000) = 0
-    phreatic_level_in_drain: confloat(ge=-10000000.000, le=10000000.000) = 0
-    water_head_during_dewatering: confloat(
-        ge=-10000000.000, le=10000000.000
-    ) = 0  # relevant for strip and column
-    tube_pressure_during_dewatering: confloat(
-        ge=-10000000.000, le=10000000.000
-    ) = 0  # relevant for the sand wall
-    time: List[confloat(ge=0, le=100000)] = []
-    underpressure: List[confloat(ge=0, le=100000)] = []
-    water_level: List[confloat(ge=-10000000.000, le=10000000.000)] = []
+    begin_time: Annotated[float, Field(ge=0, le=100000)] = 0
+    end_time: Annotated[float, Field(ge=0, le=100000)] = 0
+    under_pressure_for_strips_and_columns: Annotated[float, Field(ge=0, le=100000)] = 35
+    under_pressure_for_sand_wall: Annotated[float, Field(ge=0, le=100000)] = 35
+    start_of_drainage: Annotated[float, Field(ge=0, le=100000)] = 0
+    phreatic_level_in_drain: Annotated[
+        float, Field(ge=-10000000.000, le=10000000.000)
+    ] = 0
+    water_head_during_dewatering: Annotated[
+        float, Field(ge=-10000000.000, le=10000000.000)
+    ] = 0  # relevant for strip and column
+    tube_pressure_during_dewatering: Annotated[
+        float, Field(ge=-10000000.000, le=10000000.000)
+    ] = 0  # relevant for the sand wall
+    time: list[Annotated[float, Field(ge=0, le=100000)]] = []
+    underpressure: list[Annotated[float, Field(ge=0, le=100000)]] = []
+    water_level: list[Annotated[float, Field(ge=-10000000.000, le=10000000.000)]] = []
 
 
 class InternalProbabilisticCalculationType(IntEnum):
@@ -776,11 +770,22 @@ class InternalProbabilisticCalculationType(IntEnum):
     BandWidthAndProbabilityOfFailureMonteCarlo = 2
 
 
+class FitOptions(DSeriesInlineMappedProperties):
+    fit_maximum_number_of_iterations: Annotated[int, Field(ge=0, le=100)] = 5
+    fit_required_iteration_accuracy: Annotated[float, Field(ge=0, le=1)] = 0.0001
+    fit_required_correlation_coefficient: Annotated[float, Field(ge=0, le=1)] = 0.99
+
+
+class FitCalculation(DSeriesInlineMappedProperties):
+    is_fit_calculation: Bool = Bool.FALSE
+    fit_vertical_number: Annotated[int, Field(ge=-1, le=1000)] = 0  # index (zero-based)
+
+
 class ProbabilisticData(DSeriesInlineMappedProperties):
     reliability_x_co__ordinate: float = 0
-    residual_settlement: confloat(ge=0, le=1000) = 1
-    maximum_drawings: conint(ge=0, le=999999999) = 100
-    maximum_iterations: conint(ge=1, le=50) = 15
+    residual_settlement: Annotated[float, Field(ge=0, le=1000)] = 1
+    maximum_drawings: Annotated[int, Field(ge=0, le=999999999)] = 100
+    maximum_iterations: Annotated[int, Field(ge=1, le=50)] = 15
     reliability_type: InternalProbabilisticCalculationType = (
         InternalProbabilisticCalculationType.FOSMOrDeterministic
     )
@@ -825,38 +830,29 @@ class ProbabilisticData(DSeriesInlineMappedProperties):
         return map_values[reliability_type.value]
 
 
-class DSettlementStructure(DSeriesStructure):
+class DSettlementInputStructure(DSeriesStructure):
     """Representation of complete .sli file."""
 
     version: Version = Version()
     soil_collection: SoilCollection = SoilCollection()
     geometry_data: GeometryData = GeometryData()
-    geometry_1d_data: Optional[str]
+    geometry_1d_data: str | None = None
     run_identification: str = 2 * "\n"
-    model: Union[Model, str] = Model()
-    verticals: Union[Verticals, str] = Verticals()
-    water: Union[float, str] = 9.81
-    non__uniform_loads: Union[NonUniformLoads, str] = NonUniformLoads()
-    water_loads: Union[WaterLoads, str] = WaterLoads()
-    other_loads: Union[OtherLoads, str] = OtherLoads()
-    calculation_options: Union[CalculationOptions, str] = CalculationOptions()
-    residual_times: Union[ResidualTimes, str] = ResidualTimes()
+    model: Model = Model()
+    verticals: Verticals | str = Verticals()
+    water: float | str = 9.81
+    non__uniform_loads: NonUniformLoads | str = NonUniformLoads()
+    water_loads: WaterLoads | str = WaterLoads()
+    other_loads: OtherLoads | str = OtherLoads()
+    calculation_options: CalculationOptions | str = CalculationOptions()
+    residual_times: ResidualTimes | str = ResidualTimes()
     filter_band_width: str = cleandoc(
         """
         1 : Number of items
         0.05
         """
     )
-    pore_pressure_meters: str = ZERO_ITEMS
-    non__uniform_loads_pore_pressures: str = ZERO_ITEMS
-    other_loads_pore_pressures: str = ZERO_ITEMS
-    calculation_options_pore_pressures: str = cleandoc(
-        """
-        1 : Shear stress = TRUE
-        1 : calculation method of lateral stress ratio (k0) = Nu
-        """
-    )
-    vertical_drain: Union[VerticalDrain, str] = VerticalDrain()
+    vertical_drain: VerticalDrain | str = VerticalDrain()
     probabilistic_data: ProbabilisticData = ProbabilisticData()
     probabilistic_defaults: str = cleandoc(
         """
@@ -913,27 +909,8 @@ class DSettlementStructure(DSeriesStructure):
         ProbDefLayerDist=0
         """
     )
-    fit_options: str = cleandoc(
-        """
-        Fit Maximum Number of Iterations=5
-        Fit Required Iteration Accuracy=0.0001000000
-        Fit Required Correlation Coefficient=0.990
-        """
-    )
-    fit_calculation: str = cleandoc(
-        """
-        Is Fit Calculation=0
-        Fit Vertical Number=-1
-        """
-    )
-    eps: str = cleandoc(
-        """
-        0.00 = Dry unit weight
-        0.00 = Saturated unit weight
-        0.00 = Load
-        0.00 = Height above surface
-        """
-    )
+    fit_options: FitOptions = FitOptions()
+    fit_calculation: FitCalculation = FitCalculation()
     fit: str = ZERO_ITEMS
 
     # Custom validator
@@ -956,7 +933,7 @@ class DSettlementStructure(DSeriesStructure):
                 check_that_x_in_verticals = True
         if not (check_that_x_in_verticals):
             raise ValueError(
-                f"The x-coordinate of point_of_vertical does not correspond to an existing vertical."
+                "The x-coordinate of point_of_vertical does not correspond to an existing vertical."
             )
 
     def get_headlines_for_layers(self):
@@ -964,35 +941,35 @@ class DSettlementStructure(DSeriesStructure):
 
 
 class Stresses(DSeriesTableStructure):
-    stresses: List[Dict[str, float]]
+    stresses: list[dict[str, float]]
 
 
 class KoppejanSettlements(DSeriesTableStructure):
-    koppejansettlements: List[Dict[str, float]]
+    koppejansettlements: list[dict[str, float]]
 
 
 class Depths(DSerieListStructure):
-    depths: List[float]
+    depths: list[float]
 
 
 class Leakages(DSerieListStructure):
-    leakages: List[float]
+    leakages: list[float]
 
 
 class DrainedLayers(DSerieListStructure):
-    drainedlayers: List[int]
+    drainedlayers: list[int]
 
 
 class TimeSettlementPerLoad(DSerieMatrixStructure):
-    timesettlementperload: List[List[float]]
+    timesettlementperload: list[list[float]]
 
 
 class HorizontalDisplacements(DSerieMatrixStructure):
-    horizontaldisplacements: List[List[float]]
+    horizontaldisplacements: list[list[float]]
 
 
 class TimeDependentData(DSerieRepeatedTableStructure):
-    timedependentdata: Dict[float, List[Dict[str, float]]]
+    timedependentdata: dict[float, list[dict[str, float]]]
 
 
 class Vertical(ComplexVerticalSubstructure):
@@ -1001,36 +978,47 @@ class Vertical(ComplexVerticalSubstructure):
     id: int
     x: float
     z: float
-    time__settlement_per_load: Optional[TimeSettlementPerLoad]
+    time__settlement_per_load: TimeSettlementPerLoad | None = None
     depths: Depths
-    leakages: Optional[Leakages]
-    drained_layers: Optional[DrainedLayers]
-    stresses: Optional[Stresses]
-    koppejan_settlement: Optional[KoppejanSettlements]
-    time__dependent_data: List[TimeDependentData]
-    elasticity: Optional[float]
-    horizontal_displacements: Optional[HorizontalDisplacements]
+    leakages: Leakages | None = None
+    drained_layers: DrainedLayers | None = None
+    stresses: Stresses | None = None
+    koppejan_settlement: KoppejanSettlements | None = None
+    time__dependent_data: list[TimeDependentData]
+    elasticity: float | None = None
+    horizontal_displacements: HorizontalDisplacements | None = None
 
 
 class ResidualSettlements(DSerieOldTableStructure):
-    # TODO LIst[Dict[str, float]] but can be empty which now gives a validation error
-    residualsettlements: List[Dict[str, float]]
+    # TODO LIst[dict[str, float]] but can be empty which now gives a validation error
+    residualsettlements: list[dict[str, float]]
+
+
+class CalculationSettings(DSeriesStructure):
+    # Secondary Swelling is only available in Evaluation version (Deltares only)
+    is_secondary_swelling_used: bool = False
 
 
 class Results(DSeriesRepeatedGroupedProperties):
     """Representation of [results] group in sld file."""
 
+    calculation_settings: CalculationSettings | None = None
     verticals_count: int
-    vertical: List[Vertical]
-    residual_settlements: List[ResidualSettlements]
-    amounts_of_loads: Optional[str]
-    dissipation_in_layers: Optional[str]
-    reliability_calculation_results: Optional[str]
+    vertical: list[Vertical]
+    residual_settlements: list[ResidualSettlements]
+    amounts_of_loads: str | None = None
+    dissipation_in_layers: str | None = None
+    reliability_calculation_results: str | None = None
 
 
 class DSettlementOutputStructure(DSeriesStructure):
-    """Representation of complete .sld file, inherting
+    """Representation of complete .sld file, inheriting
     the structure of the .sli file as well."""
 
     results: Results
-    input_data: DSettlementStructure
+    input_data: DSettlementInputStructure
+
+
+class DSettlementStructure(DSeriesStructure):
+    input_data: DSettlementInputStructure = DSettlementInputStructure()
+    output_data: Results | None = None
