@@ -1,21 +1,21 @@
 from abc import ABCMeta, abstractmethod
 from pathlib import Path
-from subprocess import CompletedProcess, run
-from typing import Any, List, Optional, Type, Union
 from typing import BinaryIO
 
 from pydantic import FilePath, PositiveFloat
-from pydantic.types import confloat, conint
 
-from geolib.geometry import Point
-from geolib.models import BaseDataClass, BaseModel, BaseModelStructure
-from geolib.models.dsheetpiling.constructions import DiaphragmWall, Pile, Sheet
+from geolib.models import BaseDataClass, BaseModel
+from geolib.models.dsheetpiling.constructions import (
+    DiaphragmWall,
+    Pile,
+    Sheet,
+    VerticalBalance,
+)
 from geolib.models.meta import CONSOLE_RUN_BATCH_FLAG
 from geolib.soils import Soil
 
 from .calculation_options import CalculationOptions, CalculationOptionsPerStage
 from .dsheetpiling_parserprovider import DSheetPilingParserProvider
-from .internal import CalculationOptions as CalculationOptionsInternal
 from .internal import (
     DSheetPilingDumpStructure,
     DSheetPilingOutputStructure,
@@ -23,7 +23,6 @@ from .internal import (
     Water,
 )
 from .loads import (
-    Earthquake,
     HorizontalLineLoad,
     Moment,
     NormalForce,
@@ -36,16 +35,10 @@ from .serializer import DSheetPilingInputSerializer
 from .settings import (
     CalculationType,
     CurveSettings,
-    DesignType,
     LateralEarthPressureMethod,
     LateralEarthPressureMethodStage,
     ModelType,
     PartialFactorCalculationType,
-    PartialFactorSetCUR,
-    PartialFactorSetEC,
-    PartialFactorSetEC7NADB,
-    PartialFactorSetEC7NADNL,
-    PartialFactorSetVerifyEC,
     PassiveSide,
     Side,
     SinglePileLoadOptions,
@@ -65,16 +58,16 @@ class BaseModelType(BaseDataClass, metaclass=ABCMeta):
         raise NotImplementedError
 
     def to_internal(self):
-        return dict(self)
+        return self.model_dump()
 
 
 class SheetModelType(BaseModelType):
-    method: Optional[LateralEarthPressureMethod] = None
-    check_vertical_balance: Optional[bool] = None
-    verification: Optional[bool] = None
-    trildens_calculation: Optional[bool] = None
-    reliability_analysis: Optional[bool] = None
-    elastic_calculation: Optional[bool] = None
+    method: LateralEarthPressureMethod | None = None
+    check_vertical_balance: bool | None = None
+    verification: bool | None = None
+    trildens_calculation: bool | None = None
+    reliability_analysis: bool | None = None
+    elastic_calculation: bool | None = None
 
     @property
     def model(self) -> ModelType:
@@ -82,10 +75,11 @@ class SheetModelType(BaseModelType):
 
 
 class WoodenSheetPileModelType(BaseModelType):
-    method: Optional[LateralEarthPressureMethod] = None
-    check_vertical_balance: Optional[bool] = None
-    verification: Optional[bool] = None
-    elastic_calculation: Optional[bool] = None
+    method: LateralEarthPressureMethod | None = None
+    check_vertical_balance: bool | None = None
+    verification: bool | None = None
+    elastic_calculation: bool = True
+    wooden_sheetpiling: bool = True
 
     @property
     def model(self) -> ModelType:
@@ -93,8 +87,8 @@ class WoodenSheetPileModelType(BaseModelType):
 
 
 class SinglePileModelType(BaseModelType):
-    pile_load_option: Optional[SinglePileLoadOptions] = None
-    elastic_calculation: Optional[bool] = None
+    pile_load_option: SinglePileLoadOptions | None = None
+    elastic_calculation: bool | None = None
 
     @property
     def model(self) -> ModelType:
@@ -113,13 +107,15 @@ class SinglePileModelType(BaseModelType):
 
 
 class DiaphragmModelType(BaseModelType):
-    method: Optional[LateralEarthPressureMethod] = None
-    check_vertical_balance: Optional[bool] = None
-    verification: Optional[bool] = None
+    method: LateralEarthPressureMethod | None = None
+    check_vertical_balance: bool | None = None
+    verification: bool | None = None
+    elastic_calculation: bool = False
+    diepwand_calculation: bool = True
 
     @property
     def model(self) -> ModelType:
-        return ModelType.DIAPHRAGM_WALL
+        return ModelType.SHEET_PILING
 
 
 class DSheetPilingModel(BaseModel):
@@ -129,21 +125,25 @@ class DSheetPilingModel(BaseModel):
     This model can read, modify and create \*.shi files, read \*.shd and \*.err files.
     """
 
-    current_stage: Optional[int] = None  # Forces user to always set a stage.
-    datastructure: Union[
-        DSheetPilingStructure, DSheetPilingDumpStructure
-    ] = DSheetPilingStructure()
+    current_stage: int | None = None  # Forces user to always set a stage.
+    datastructure: DSheetPilingStructure | DSheetPilingDumpStructure = (
+        DSheetPilingStructure()
+    )
 
     @property
-    def parser_provider_type(self) -> Type[DSheetPilingParserProvider]:
+    def parser_provider_type(self) -> type[DSheetPilingParserProvider]:
         return DSheetPilingParserProvider
 
     @property
-    def console_path(self) -> Path:
-        return Path("DSheetPilingConsole/DSheetPilingConsole.exe")
+    def default_console_path(self) -> Path:
+        return Path("DSheetPiling/DSheetPiling.exe")
 
     @property
-    def console_flags(self) -> List[str]:
+    def custom_console_path(self) -> Path:
+        return self.get_meta_property("dsheetpiling_console_path")
+
+    @property
+    def console_flags(self) -> list[str]:
         return [CONSOLE_RUN_BATCH_FLAG]
 
     @property
@@ -151,15 +151,15 @@ class DSheetPilingModel(BaseModel):
         return self.datastructure.dumpfile.output_data
 
     @property
-    def model_type(self) -> Union[str, ModelType]:
+    def model_type(self) -> str | ModelType:
         return self.datastructure.input_data.model.model
 
-    def serialize(self, filename: Union[FilePath, BinaryIO]):
-        ds = self.datastructure.input_data.dict()
+    def serialize(self, filename: FilePath | BinaryIO):
+        ds = self.datastructure.input_data.model_dump()
         ds.update(
             {
-                "version": self.datastructure.version.dict(),
-                "version_externals": self.datastructure.version_externals.dict(),
+                "version": self.datastructure.input_data.version.model_dump(),
+                "version_externals": self.datastructure.input_data.version_externals.model_dump(),
             }
         )
         serializer = DSheetPilingInputSerializer(ds=ds)
@@ -172,7 +172,7 @@ class DSheetPilingModel(BaseModel):
         _map_method_b_available = {
             VerifyType.CUR: self.datastructure.input_data.calculation_options.curmethod,
             VerifyType.EC7NL: self.datastructure.input_data.calculation_options.ec7nlmethod,
-            VerifyType.EC7BE: self.datastructure.input_data.calculation_options.nbmethod,
+            VerifyType.EC7BE: self.datastructure.input_data.calculation_options.ec7bemethod,
         }
         if (
             self.datastructure.input_data.calculation_options.inputcalculationtype
@@ -256,7 +256,7 @@ class DSheetPilingModel(BaseModel):
                 f"calculation_options_per_stage is not required for stage {stage_id}."
             )
 
-    def _get_default_stage_none_provided(self, stage_id: Optional[int]) -> int:
+    def _get_default_stage_none_provided(self, stage_id: int | None) -> int:
         stage_id = stage_id if stage_id is not None else self.current_stage
         if stage_id is None:
             raise ValueError("No stages available yet: add a stage first.")
@@ -290,7 +290,9 @@ class DSheetPilingModel(BaseModel):
             raise ValueError(
                 f"model should be of subtype CalculationOptions, received {calculation_options}"
             )
-        self.datastructure.input_data.set_calculation_options(**dict(calculation_options))
+        self.datastructure.input_data.set_calculation_options(
+            **calculation_options.model_dump()
+        )
 
     def set_curve_settings(
         self,
@@ -379,7 +381,7 @@ class DSheetPilingModel(BaseModel):
         )
 
     def set_construction(
-        self, top_level: float, elements: List[Union[Sheet, DiaphragmWall, Pile]]
+        self, top_level: float, elements: list[Sheet | DiaphragmWall | Pile]
     ) -> None:
         """Sets construction for the DSheetPilingModel.
 
@@ -394,25 +396,31 @@ class DSheetPilingModel(BaseModel):
             top_level=top_level, elements=[element.to_internal() for element in elements]
         )
 
-    def add_load(
-        self,
-        load: Union[
-            Moment,
-            HorizontalLineLoad,
-            NormalForce,
-            SoilDisplacement,
-            Earthquake,
-            UniformLoad,
-        ],
-        stage_id: int,
-    ):
-        """Adds other loads of type Moment, HorizontalLineLoad, NormalForce, SoilDisplacement or Earthquake
+    def set_vertical_balance(self, vertical_balance: VerticalBalance) -> None:
+        """Sets the vertical balance parameters
+
+        The parameters are set in [VERTICAL BALANCE]
 
         Args:
-            load: Add a load with the types of Moment, HorizontalLineLoad, NormalForce, SoilDisplacement or Earthquake.
-            Note that SoilDisplacement and Earthquake are only valid for a Pile construction.
+            vertical_balance: VerticalBalance, holds the vertical balance parameters
+        """
+        self.datastructure.input_data.set_vertical_balance(
+            vertical_balance=vertical_balance.to_internal()
+        )
+
+    def add_load(
+        self,
+        load: Moment | HorizontalLineLoad | NormalForce | SoilDisplacement | UniformLoad,
+        stage_id: int,
+    ):
+        """Adds other loads of type Moment, HorizontalLineLoad, NormalForce, SoilDisplacement or UniformLoad
+
+        Args:
+            load: Add a load with the types of Moment, HorizontalLineLoad, NormalForce, SoilDisplacement or UniformLoad.
             stage_id: Load is added to this stage.
 
+        Note: SoilDisplacement and UniformLoad are only valid for a sheetpiling construction.
+
         Raises:
             ValueError: When non-existing stage_id is passed.
             ValueError: When a verification calculation is selected but duration_type and load_type are not defined for the load.
@@ -438,7 +446,7 @@ class DSheetPilingModel(BaseModel):
 
     def add_anchor_or_strut(
         self,
-        support: Union[Anchor, Strut],
+        support: Anchor | Strut,
         stage_id: int,
         pre_stress: PositiveFloat = 0,
     ) -> None:
@@ -474,7 +482,7 @@ class DSheetPilingModel(BaseModel):
 
     def add_support(
         self,
-        support: Union[SpringSupport, RigidSupport],
+        support: SpringSupport | RigidSupport,
         stage_id: int,
     ) -> None:
         """Add spring or rigid support to a stage.
