@@ -3,31 +3,23 @@ from geolib.models.dseries_parser import DSeriesInlineMappedProperties
 
 
 class PartialFactorsEurocodeDa1Set1(DSeriesInlineMappedProperties):
-    safetyfactorgammad: float = 1.00
-    safetyfactoreta: float = 1.00
     loadfactorpermunfav: float = 1.00
     loadfactorpermfav: float = 1.00
     loadfactorvarunfav: float = 1.00
     loadfactorvarfav: float = 0.00
-    loadfactorpermunfavmultiply: float = 1.00
-    loadfactorvarunfavmultiply: float = 1.00
-    loadfactorpermunfavcalc: float = 0.0000
-    loadfactorvarunfavcalc: float = 0.0000
     constructloadfactorpermfav: float = 1.00
-    constructloadfactorvarfav: float = 1.00
-    constructloadfactorpermunfavmultiply: float = 1.00
-    constructloadfactorvarunfavmultiply: float = 1.00
-    constructloadfactorpermunfavcalc: float = 1.0000
-    constructloadfactorvarunfavcalc: float = 1.0000
+    constructloadfactorvarfav: float = 0.00
+    constructloadfactorpermunfavcalc: float = 1.00
+    constructloadfactorvarunfavcalc: float = 1.00
     effectfactor: float = 1.35
     effectfactorvarunfav: float = 1.10
     materialfactorcohesion: float = 1.00
-    materialfactorundrainedshearstrength: float = 1.00
     materialfactortgphi: float = 1.000
     materialfactorsubgradereaction: float = 1.00
     resistancefactor: float = 1.00
     geometryincretainingheight: float = 10.00
     geometrymaxincretainingheight: float = 0.50
+    geometryincretainingheightdry: float = 0.00
     geometrydeltapassivesurfacelevel: float = 0.00
     geometrydeltapassivephreaticline: float = 0.00
     geometrydeltaactivephreaticline: float = 0.00
@@ -40,31 +32,23 @@ class PartialFactorsEurocodeDa1Set1(DSeriesInlineMappedProperties):
 
 
 class PartialFactorsEurocodeDa1Set2(DSeriesInlineMappedProperties):
-    safetyfactorgammad: float = 1.00
-    safetyfactoreta: float = 1.00
     loadfactorpermunfav: float = 1.00
     loadfactorpermfav: float = 1.00
     loadfactorvarunfav: float = 1.30
     loadfactorvarfav: float = 0.00
-    loadfactorpermunfavmultiply: float = 1.00
-    loadfactorvarunfavmultiply: float = 1.00
-    loadfactorpermunfavcalc: float = 0.0000
-    loadfactorvarunfavcalc: float = 0.0000
     constructloadfactorpermfav: float = 1.00
     constructloadfactorvarfav: float = 1.00
-    constructloadfactorpermunfavmultiply: float = 1.00
-    constructloadfactorvarunfavmultiply: float = 1.00
-    constructloadfactorpermunfavcalc: float = 1.0000
-    constructloadfactorvarunfavcalc: float = 1.0000
+    constructloadfactorpermunfavcalc: float = 1.00
+    constructloadfactorvarunfavcalc: float = 1.00
     effectfactor: float = 1.00
     effectfactorvarunfav: float = 1.00
     materialfactorcohesion: float = 1.25
-    materialfactorundrainedshearstrength: float = 1.00
     materialfactortgphi: float = 1.250
     materialfactorsubgradereaction: float = 1.00
     resistancefactor: float = 1.00
     geometryincretainingheight: float = 10.00
     geometrymaxincretainingheight: float = 0.50
+    geometryincretainingheightdry: float = 0.00
     geometrydeltapassivesurfacelevel: float = 0.00
     geometrydeltapassivephreaticline: float = 0.00
     geometrydeltaactivephreaticline: float = 0.00
@@ -77,31 +61,23 @@ class PartialFactorsEurocodeDa1Set2(DSeriesInlineMappedProperties):
 
 
 class PartialFactorsEurocodeDa2(DSeriesInlineMappedProperties):
-    safetyfactorgammad: float = 1.00
-    safetyfactoreta: float = 1.00
     loadfactorpermunfav: float = 1.00
     loadfactorpermfav: float = 1.00
     loadfactorvarunfav: float = 1.00
     loadfactorvarfav: float = 0.00
-    loadfactorpermunfavmultiply: float = 1.00
-    loadfactorvarunfavmultiply: float = 1.00
-    loadfactorpermunfavcalc: float = 0.0000
-    loadfactorvarunfavcalc: float = 0.0000
     constructloadfactorpermfav: float = 1.00
     constructloadfactorvarfav: float = 1.00
-    constructloadfactorpermunfavmultiply: float = 1.00
-    constructloadfactorvarunfavmultiply: float = 1.00
-    constructloadfactorpermunfavcalc: float = 1.0000
-    constructloadfactorvarunfavcalc: float = 1.0000
+    constructloadfactorpermunfavcalc: float = 1.00
+    constructloadfactorvarunfavcalc: float = 1.00
     effectfactor: float = 1.35
     effectfactorvarunfav: float = 1.10
     materialfactorcohesion: float = 1.00
-    materialfactorundrainedshearstrength: float = 1.00
     materialfactortgphi: float = 1.000
     materialfactorsubgradereaction: float = 1.00
     resistancefactor: float = 1.40
     geometryincretainingheight: float = 10.00
     geometrymaxincretainingheight: float = 0.50
+    geometryincretainingheightdry: float = 0.00
     geometrydeltapassivesurfacelevel: float = 0.00
     geometrydeltapassivephreaticline: float = 0.00
     geometrydeltaactivephreaticline: float = 0.00
@@ -114,31 +90,23 @@ class PartialFactorsEurocodeDa2(DSeriesInlineMappedProperties):
 
 
 class PartialFactorsEurocodeDa3(DSeriesInlineMappedProperties):
-    safetyfactorgammad: float = 1.00
-    safetyfactoreta: float = 1.00
     loadfactorpermunfav: float = 1.00
     loadfactorpermfav: float = 1.00
     loadfactorvarunfav: float = 1.30
     loadfactorvarfav: float = 0.00
-    loadfactorpermunfavmultiply: float = 1.00
-    loadfactorvarunfavmultiply: float = 1.00
-    loadfactorpermunfavcalc: float = 0.0000
-    loadfactorvarunfavcalc: float = 0.0000
     constructloadfactorpermfav: float = 1.00
     constructloadfactorvarfav: float = 1.00
-    constructloadfactorpermunfavmultiply: float = 1.00
-    constructloadfactorvarunfavmultiply: float = 1.00
-    constructloadfactorpermunfavcalc: float = 1.0000
-    constructloadfactorvarunfavcalc: float = 1.0000
+    constructloadfactorpermunfavcalc: float = 1.00
+    constructloadfactorvarunfavcalc: float = 1.00
     effectfactor: float = 1.00
     effectfactorvarunfav: float = 1.00
     materialfactorcohesion: float = 1.25
-    materialfactorundrainedshearstrength: float = 1.00
     materialfactortgphi: float = 1.250
     materialfactorsubgradereaction: float = 1.00
     resistancefactor: float = 1.00
     geometryincretainingheight: float = 10.00
     geometrymaxincretainingheight: float = 0.50
+    geometryincretainingheightdry: float = 0.00
     geometrydeltapassivesurfacelevel: float = 0.00
     geometrydeltapassivephreaticline: float = 0.00
     geometrydeltaactivephreaticline: float = 0.00
@@ -151,31 +119,23 @@ class PartialFactorsEurocodeDa3(DSeriesInlineMappedProperties):
 
 
 class PartialFactorsEc7Nl0(DSeriesInlineMappedProperties):
-    safetyfactorgammad: float = 1.00
-    safetyfactoreta: float = 1.00
     loadfactorpermunfav: float = 1.00
     loadfactorpermfav: float = 1.00
     loadfactorvarunfav: float = 1.00
     loadfactorvarfav: float = 0.00
-    loadfactorpermunfavmultiply: float = 1.00
-    loadfactorvarunfavmultiply: float = 1.00
-    loadfactorpermunfavcalc: float = 0.0000
-    loadfactorvarunfavcalc: float = 0.0000
     constructloadfactorpermfav: float = 1.00
     constructloadfactorvarfav: float = 1.00
-    constructloadfactorpermunfavmultiply: float = 1.00
-    constructloadfactorvarunfavmultiply: float = 1.00
-    constructloadfactorpermunfavcalc: float = 1.0000
-    constructloadfactorvarunfavcalc: float = 1.0000
+    constructloadfactorpermunfavcalc: float = 1.00
+    constructloadfactorvarunfavcalc: float = 1.00
     effectfactor: float = 1.00
     effectfactorvarunfav: float = 1.00
     materialfactorcohesion: float = 1.00
-    materialfactorundrainedshearstrength: float = 1.00
     materialfactortgphi: float = 1.050
     materialfactorsubgradereaction: float = 1.30
     resistancefactor: float = 1.00
     geometryincretainingheight: float = 10.00
     geometrymaxincretainingheight: float = 0.50
+    geometryincretainingheightdry: float = 0.00
     geometrydeltapassivesurfacelevel: float = 0.00
     geometrydeltapassivephreaticline: float = 0.15
     geometrydeltaactivephreaticline: float = 0.05
@@ -188,31 +148,23 @@ class PartialFactorsEc7Nl0(DSeriesInlineMappedProperties):
 
 
 class PartialFactorsEc7Nl1(DSeriesInlineMappedProperties):
-    safetyfactorgammad: float = 1.00
-    safetyfactoreta: float = 1.00
     loadfactorpermunfav: float = 1.00
     loadfactorpermfav: float = 1.00
     loadfactorvarunfav: float = 1.00
     loadfactorvarfav: float = 0.00
-    loadfactorpermunfavmultiply: float = 1.00
-    loadfactorvarunfavmultiply: float = 1.00
-    loadfactorpermunfavcalc: float = 0.0000
-    loadfactorvarunfavcalc: float = 0.0000
     constructloadfactorpermfav: float = 1.00
     constructloadfactorvarfav: float = 1.00
-    constructloadfactorpermunfavmultiply: float = 1.00
-    constructloadfactorvarunfavmultiply: float = 1.00
-    constructloadfactorpermunfavcalc: float = 1.0000
-    constructloadfactorvarunfavcalc: float = 1.0000
+    constructloadfactorpermunfavcalc: float = 1.00
+    constructloadfactorvarunfavcalc: float = 1.00
     effectfactor: float = 1.00
     effectfactorvarunfav: float = 1.00
     materialfactorcohesion: float = 1.15
-    materialfactorundrainedshearstrength: float = 1.00
     materialfactortgphi: float = 1.150
     materialfactorsubgradereaction: float = 1.30
     resistancefactor: float = 1.00
     geometryincretainingheight: float = 10.00
     geometrymaxincretainingheight: float = 0.50
+    geometryincretainingheightdry: float = 0.00
     geometrydeltapassivesurfacelevel: float = 0.00
     geometrydeltapassivephreaticline: float = 0.20
     geometrydeltaactivephreaticline: float = 0.05
@@ -225,31 +177,23 @@ class PartialFactorsEc7Nl1(DSeriesInlineMappedProperties):
 
 
 class PartialFactorsEc7Nl2(DSeriesInlineMappedProperties):
-    safetyfactorgammad: float = 1.00
-    safetyfactoreta: float = 1.00
     loadfactorpermunfav: float = 1.00
     loadfactorpermfav: float = 1.00
     loadfactorvarunfav: float = 1.00
     loadfactorvarfav: float = 0.00
-    loadfactorpermunfavmultiply: float = 1.00
-    loadfactorvarunfavmultiply: float = 1.00
-    loadfactorpermunfavcalc: float = 0.0000
-    loadfactorvarunfavcalc: float = 0.0000
     constructloadfactorpermfav: float = 1.00
     constructloadfactorvarfav: float = 1.00
-    constructloadfactorpermunfavmultiply: float = 1.00
-    constructloadfactorvarunfavmultiply: float = 1.00
-    constructloadfactorpermunfavcalc: float = 1.0000
-    constructloadfactorvarunfavcalc: float = 1.0000
+    constructloadfactorpermunfavcalc: float = 1.00
+    constructloadfactorvarunfavcalc: float = 1.00
     effectfactor: float = 1.00
     effectfactorvarunfav: float = 1.00
     materialfactorcohesion: float = 1.25
-    materialfactorundrainedshearstrength: float = 1.00
     materialfactortgphi: float = 1.175
     materialfactorsubgradereaction: float = 1.30
     resistancefactor: float = 1.00
     geometryincretainingheight: float = 10.00
     geometrymaxincretainingheight: float = 0.50
+    geometryincretainingheightdry: float = 0.00
     geometrydeltapassivesurfacelevel: float = 0.00
     geometrydeltapassivephreaticline: float = 0.25
     geometrydeltaactivephreaticline: float = 0.05
@@ -262,31 +206,23 @@ class PartialFactorsEc7Nl2(DSeriesInlineMappedProperties):
 
 
 class PartialFactorsEc7Nl3(DSeriesInlineMappedProperties):
-    safetyfactorgammad: float = 1.00
-    safetyfactoreta: float = 1.00
     loadfactorpermunfav: float = 1.00
     loadfactorpermfav: float = 1.00
     loadfactorvarunfav: float = 1.25
     loadfactorvarfav: float = 0.00
-    loadfactorpermunfavmultiply: float = 1.00
-    loadfactorvarunfavmultiply: float = 1.00
-    loadfactorpermunfavcalc: float = 0.0000
-    loadfactorvarunfavcalc: float = 0.0000
     constructloadfactorpermfav: float = 1.00
     constructloadfactorvarfav: float = 1.00
-    constructloadfactorpermunfavmultiply: float = 1.00
-    constructloadfactorvarunfavmultiply: float = 1.00
-    constructloadfactorpermunfavcalc: float = 1.0000
-    constructloadfactorvarunfavcalc: float = 1.0000
+    constructloadfactorpermunfavcalc: float = 1.00
+    constructloadfactorvarunfavcalc: float = 1.00
     effectfactor: float = 1.00
     effectfactorvarunfav: float = 1.00
     materialfactorcohesion: float = 1.40
-    materialfactorundrainedshearstrength: float = 1.00
     materialfactortgphi: float = 1.200
     materialfactorsubgradereaction: float = 1.30
     resistancefactor: float = 1.00
     geometryincretainingheight: float = 10.00
     geometrymaxincretainingheight: float = 0.50
+    geometryincretainingheightdry: float = 0.00
     geometrydeltapassivesurfacelevel: float = 0.00
     geometrydeltapassivephreaticline: float = 0.25
     geometrydeltaactivephreaticline: float = 0.05
@@ -298,32 +234,24 @@ class PartialFactorsEc7Nl3(DSeriesInlineMappedProperties):
     verticalbalancegammamb: float = 1.25
 
 
-class PartialFactorsEc7BSet1(DSeriesInlineMappedProperties):
-    safetyfactorgammad: float = 1.00
-    safetyfactoreta: float = 1.00
+class PartialFactorsEc7BE1Set1(DSeriesInlineMappedProperties):
     loadfactorpermunfav: float = 1.00
     loadfactorpermfav: float = 1.00
     loadfactorvarunfav: float = 1.00
     loadfactorvarfav: float = 0.00
-    loadfactorpermunfavmultiply: float = 1.00
-    loadfactorvarunfavmultiply: float = 1.00
-    loadfactorpermunfavcalc: float = 0.0000
-    loadfactorvarunfavcalc: float = 0.0000
     constructloadfactorpermfav: float = 1.00
     constructloadfactorvarfav: float = 1.00
-    constructloadfactorpermunfavmultiply: float = 1.00
-    constructloadfactorvarunfavmultiply: float = 1.00
-    constructloadfactorpermunfavcalc: float = 1.0000
-    constructloadfactorvarunfavcalc: float = 1.0000
-    effectfactor: float = 1.35
-    effectfactorvarunfav: float = 1.10
+    constructloadfactorpermunfavcalc: float = 1.00
+    constructloadfactorvarunfavcalc: float = 1.00
+    effectfactor: float = 1.2
+    effectfactorvarunfav: float = 1.083
     materialfactorcohesion: float = 1.00
-    materialfactorundrainedshearstrength: float = 1.00
     materialfactortgphi: float = 1.000
     materialfactorsubgradereaction: float = 1.00
     resistancefactor: float = 1.00
-    geometryincretainingheight: float = 10.00
-    geometrymaxincretainingheight: float = 0.50
+    geometryincretainingheight: float = 0.00
+    geometrymaxincretainingheight: float = 0.00
+    geometryincretainingheightdry: float = 0.00
     geometrydeltapassivesurfacelevel: float = 0.00
     geometrydeltapassivephreaticline: float = 0.00
     geometrydeltaactivephreaticline: float = 0.00
@@ -331,36 +259,86 @@ class PartialFactorsEc7BSet1(DSeriesInlineMappedProperties):
     overallstabilityfactorcohesion: float = 1.00
     overallstabilityfactortgphi: float = 1.00
     overallstabilityfactorunitweight: float = 1.00
-    factorrepvaluesmdpmax: float = 0.00
-    verticalbalancegammamb: float = 1.20
+    factorrepvaluesmdpmax: float = 1.00
+    verticalbalancegammamb: float = 1.00
 
 
-class PartialFactorsEc7BSet2(DSeriesInlineMappedProperties):
-    safetyfactorgammad: float = 1.00
-    safetyfactoreta: float = 1.00
+class PartialFactorsEc7BE1Set2(DSeriesInlineMappedProperties):
     loadfactorpermunfav: float = 1.00
     loadfactorpermfav: float = 1.00
     loadfactorvarunfav: float = 1.10
     loadfactorvarfav: float = 0.00
-    loadfactorpermunfavmultiply: float = 1.00
-    loadfactorvarunfavmultiply: float = 1.00
-    loadfactorpermunfavcalc: float = 0.0000
-    loadfactorvarunfavcalc: float = 0.0000
     constructloadfactorpermfav: float = 1.00
     constructloadfactorvarfav: float = 1.00
-    constructloadfactorpermunfavmultiply: float = 1.00
-    constructloadfactorvarunfavmultiply: float = 1.00
-    constructloadfactorpermunfavcalc: float = 1.0000
-    constructloadfactorvarunfavcalc: float = 1.0000
+    constructloadfactorpermunfavcalc: float = 1.00
+    constructloadfactorvarunfavcalc: float = 1.00
     effectfactor: float = 1.00
     effectfactorvarunfav: float = 1.00
-    materialfactorcohesion: float = 1.25
-    materialfactorundrainedshearstrength: float = 1.00
-    materialfactortgphi: float = 1.250
+    materialfactorcohesion: float = 1.10
+    materialfactortgphi: float = 1.10
     materialfactorsubgradereaction: float = 1.00
     resistancefactor: float = 1.00
     geometryincretainingheight: float = 10.00
     geometrymaxincretainingheight: float = 0.50
+    geometryincretainingheightdry: float = 0.30
+    geometrydeltapassivesurfacelevel: float = 0.00
+    geometrydeltapassivephreaticline: float = 0.00
+    geometrydeltaactivephreaticline: float = 0.00
+    overallstabilityfactordrivingmoment: float = 1.00
+    overallstabilityfactorcohesion: float = 1.10
+    overallstabilityfactortgphi: float = 1.10
+    overallstabilityfactorunitweight: float = 1.00
+    factorrepvaluesmdpmax: float = 0.00
+    verticalbalancegammamb: float = 1.30
+
+
+class PartialFactorsEc7BE2Set1(DSeriesInlineMappedProperties):
+    loadfactorpermunfav: float = 1.00
+    loadfactorpermfav: float = 1.00
+    loadfactorvarunfav: float = 1.00
+    loadfactorvarfav: float = 0.00
+    constructloadfactorpermfav: float = 1.00
+    constructloadfactorvarfav: float = 1.00
+    constructloadfactorpermunfavcalc: float = 1.00
+    constructloadfactorvarunfavcalc: float = 1.00
+    effectfactor: float = 1.35
+    effectfactorvarunfav: float = 1.111
+    materialfactorcohesion: float = 1.00
+    materialfactortgphi: float = 1.000
+    materialfactorsubgradereaction: float = 1.00
+    resistancefactor: float = 1.00
+    geometryincretainingheight: float = 0.00
+    geometrymaxincretainingheight: float = 0.00
+    geometryincretainingheightdry: float = 0.00
+    geometrydeltapassivesurfacelevel: float = 0.00
+    geometrydeltapassivephreaticline: float = 0.00
+    geometrydeltaactivephreaticline: float = 0.00
+    overallstabilityfactordrivingmoment: float = 1.00
+    overallstabilityfactorcohesion: float = 1.00
+    overallstabilityfactortgphi: float = 1.00
+    overallstabilityfactorunitweight: float = 1.00
+    factorrepvaluesmdpmax: float = 1.00
+    verticalbalancegammamb: float = 1.00
+
+
+class PartialFactorsEc7BE2Set2(DSeriesInlineMappedProperties):
+    loadfactorpermunfav: float = 1.00
+    loadfactorpermfav: float = 1.00
+    loadfactorvarunfav: float = 1.10
+    loadfactorvarfav: float = 0.00
+    constructloadfactorpermfav: float = 1.00
+    constructloadfactorvarfav: float = 1.00
+    constructloadfactorpermunfavcalc: float = 1.00
+    constructloadfactorvarunfavcalc: float = 1.00
+    effectfactor: float = 1.00
+    effectfactorvarunfav: float = 1.00
+    materialfactorcohesion: float = 1.25
+    materialfactortgphi: float = 1.25
+    materialfactorsubgradereaction: float = 1.00
+    resistancefactor: float = 1.00
+    geometryincretainingheight: float = 10.00
+    geometrymaxincretainingheight: float = 0.50
+    geometryincretainingheightdry: float = 0.30
     geometrydeltapassivesurfacelevel: float = 0.00
     geometrydeltapassivephreaticline: float = 0.00
     geometrydeltaactivephreaticline: float = 0.00
@@ -368,36 +346,86 @@ class PartialFactorsEc7BSet2(DSeriesInlineMappedProperties):
     overallstabilityfactorcohesion: float = 1.25
     overallstabilityfactortgphi: float = 1.25
     overallstabilityfactorunitweight: float = 1.00
-    factorrepvaluesmdpmax: float = 0.00
-    verticalbalancegammamb: float = 1.20
+    factorrepvaluesmdpmax: float = 1.00
+    verticalbalancegammamb: float = 1.30
 
 
-class PartialFactorsCurI(DSeriesInlineMappedProperties):
-    safetyfactorgammad: float = 1.00
-    safetyfactoreta: float = 1.00
+class PartialFactorsEc7BE3Set1(DSeriesInlineMappedProperties):
     loadfactorpermunfav: float = 1.00
     loadfactorpermfav: float = 1.00
     loadfactorvarunfav: float = 1.00
     loadfactorvarfav: float = 0.00
-    loadfactorpermunfavmultiply: float = 1.00
-    loadfactorvarunfavmultiply: float = 1.00
-    loadfactorpermunfavcalc: float = 0.0000
-    loadfactorvarunfavcalc: float = 0.0000
     constructloadfactorpermfav: float = 1.00
     constructloadfactorvarfav: float = 1.00
-    constructloadfactorpermunfavmultiply: float = 1.00
-    constructloadfactorvarunfavmultiply: float = 1.00
-    constructloadfactorpermunfavcalc: float = 1.0000
-    constructloadfactorvarunfavcalc: float = 1.0000
+    constructloadfactorpermunfavcalc: float = 1.00
+    constructloadfactorvarunfavcalc: float = 1.00
+    effectfactor: float = 1.50
+    effectfactorvarunfav: float = 1.20
+    materialfactorcohesion: float = 1.00
+    materialfactortgphi: float = 1.000
+    materialfactorsubgradereaction: float = 1.00
+    resistancefactor: float = 1.00
+    geometryincretainingheight: float = 0.00
+    geometrymaxincretainingheight: float = 0.00
+    geometryincretainingheightdry: float = 0.00
+    geometrydeltapassivesurfacelevel: float = 0.00
+    geometrydeltapassivephreaticline: float = 0.00
+    geometrydeltaactivephreaticline: float = 0.00
+    overallstabilityfactordrivingmoment: float = 1.00
+    overallstabilityfactorcohesion: float = 1.00
+    overallstabilityfactortgphi: float = 1.00
+    overallstabilityfactorunitweight: float = 1.00
+    factorrepvaluesmdpmax: float = 1.00
+    verticalbalancegammamb: float = 1.00
+
+
+class PartialFactorsEc7BE3Set2(DSeriesInlineMappedProperties):
+    loadfactorpermunfav: float = 1.00
+    loadfactorpermfav: float = 1.00
+    loadfactorvarunfav: float = 1.20
+    loadfactorvarfav: float = 0.00
+    constructloadfactorpermfav: float = 1.00
+    constructloadfactorvarfav: float = 1.00
+    constructloadfactorpermunfavcalc: float = 1.00
+    constructloadfactorvarunfavcalc: float = 1.00
+    effectfactor: float = 1.00
+    effectfactorvarunfav: float = 1.00
+    materialfactorcohesion: float = 1.40
+    materialfactortgphi: float = 1.40
+    materialfactorsubgradereaction: float = 1.00
+    resistancefactor: float = 1.00
+    geometryincretainingheight: float = 10.00
+    geometrymaxincretainingheight: float = 0.50
+    geometryincretainingheightdry: float = 0.30
+    geometrydeltapassivesurfacelevel: float = 0.00
+    geometrydeltapassivephreaticline: float = 0.00
+    geometrydeltaactivephreaticline: float = 0.00
+    overallstabilityfactordrivingmoment: float = 1.00
+    overallstabilityfactorcohesion: float = 1.40
+    overallstabilityfactortgphi: float = 1.40
+    overallstabilityfactorunitweight: float = 1.00
+    factorrepvaluesmdpmax: float = 1.00
+    verticalbalancegammamb: float = 1.30
+
+
+class PartialFactorsCurI(DSeriesInlineMappedProperties):
+    loadfactorpermunfav: float = 1.00
+    loadfactorpermfav: float = 1.00
+    loadfactorvarunfav: float = 1.00
+    loadfactorvarfav: float = 0.00
+    constructloadfactorpermfav: float = 1.00
+    constructloadfactorvarfav: float = 1.00
+    constructloadfactorpermunfavcalc: float = 1.00
+    constructloadfactorvarunfavcalc: float = 1.00
     effectfactor: float = 1.00
     effectfactorvarunfav: float = 1.00
     materialfactorcohesion: float = 1.00
-    materialfactorundrainedshearstrength: float = 1.00
     materialfactortgphi: float = 1.050
     materialfactorsubgradereaction: float = 1.30
     resistancefactor: float = 1.00
     geometryincretainingheight: float = 0.00
     geometrymaxincretainingheight: float = 0.00
+    geometryincretainingheightdry: float = 0.00
     geometrydeltapassivesurfacelevel: float = 0.20
     geometrydeltapassivephreaticline: float = 0.15
     geometrydeltaactivephreaticline: float = 0.05
@@ -410,31 +438,23 @@ class PartialFactorsCurI(DSeriesInlineMappedProperties):
 
 
 class PartialFactorsCurIi(DSeriesInlineMappedProperties):
-    safetyfactorgammad: float = 1.00
-    safetyfactoreta: float = 1.00
     loadfactorpermunfav: float = 1.00
     loadfactorpermfav: float = 1.00
     loadfactorvarunfav: float = 1.00
     loadfactorvarfav: float = 0.00
-    loadfactorpermunfavmultiply: float = 1.00
-    loadfactorvarunfavmultiply: float = 1.00
-    loadfactorpermunfavcalc: float = 0.0000
-    loadfactorvarunfavcalc: float = 0.0000
     constructloadfactorpermfav: float = 1.00
     constructloadfactorvarfav: float = 1.00
-    constructloadfactorpermunfavmultiply: float = 1.00
-    constructloadfactorvarunfavmultiply: float = 1.00
-    constructloadfactorpermunfavcalc: float = 1.0000
-    constructloadfactorvarunfavcalc: float = 1.0000
+    constructloadfactorpermunfavcalc: float = 1.00
+    constructloadfactorvarunfavcalc: float = 1.00
     effectfactor: float = 1.00
     effectfactorvarunfav: float = 1.00
     materialfactorcohesion: float = 1.00
-    materialfactorundrainedshearstrength: float = 1.00
     materialfactortgphi: float = 1.150
     materialfactorsubgradereaction: float = 1.30
     resistancefactor: float = 1.00
     geometryincretainingheight: float = 0.00
     geometrymaxincretainingheight: float = 0.00
+    geometryincretainingheightdry: float = 0.00
     geometrydeltapassivesurfacelevel: float = 0.30
     geometrydeltapassivephreaticline: float = 0.20
     geometrydeltaactivephreaticline: float = 0.05
@@ -447,31 +467,23 @@ class PartialFactorsCurIi(DSeriesInlineMappedProperties):
 
 
 class PartialFactorsCurIii(DSeriesInlineMappedProperties):
-    safetyfactorgammad: float = 1.00
-    safetyfactoreta: float = 1.00
     loadfactorpermunfav: float = 1.00
     loadfactorpermfav: float = 1.00
     loadfactorvarunfav: float = 1.25
     loadfactorvarfav: float = 0.00
-    loadfactorpermunfavmultiply: float = 1.00
-    loadfactorvarunfavmultiply: float = 1.00
-    loadfactorpermunfavcalc: float = 0.0000
-    loadfactorvarunfavcalc: float = 0.0000
     constructloadfactorpermfav: float = 1.00
     constructloadfactorvarfav: float = 1.00
-    constructloadfactorpermunfavmultiply: float = 1.00
-    constructloadfactorvarunfavmultiply: float = 1.00
-    constructloadfactorpermunfavcalc: float = 1.0000
-    constructloadfactorvarunfavcalc: float = 1.0000
+    constructloadfactorpermunfavcalc: float = 1.00
+    constructloadfactorvarunfavcalc: float = 1.00
     effectfactor: float = 1.00
     effectfactorvarunfav: float = 1.00
     materialfactorcohesion: float = 1.10
-    materialfactorundrainedshearstrength: float = 1.00
     materialfactortgphi: float = 1.200
     materialfactorsubgradereaction: float = 1.30
     resistancefactor: float = 1.00
     geometryincretainingheight: float = 0.00
     geometrymaxincretainingheight: float = 0.00
+    geometryincretainingheightdry: float = 0.00
     geometrydeltapassivesurfacelevel: float = 0.35
     geometrydeltapassivephreaticline: float = 0.25
     geometrydeltaactivephreaticline: float = 0.05
@@ -481,114 +493,3 @@ class PartialFactorsCurIii(DSeriesInlineMappedProperties):
     overallstabilityfactorunitweight: float = 1.00
     factorrepvaluesmdpmax: float = 0.00
     verticalbalancegammamb: float = 1.25
-
-
-class PartialFactorsEc7SeVk1(DSeriesInlineMappedProperties):
-    safetyfactorgammad: float = 0.83
-    safetyfactoreta: float = 1.00
-    loadfactorpermunfav: float = 1.00
-    loadfactorpermfav: float = 1.00
-    loadfactorvarunfav: float = 1.00
-    loadfactorvarfav: float = 0.00
-    loadfactorpermunfavmultiply: float = 1.10
-    loadfactorvarunfavmultiply: float = 1.40
-    loadfactorpermunfavcalc: float = 0.9130
-    loadfactorvarunfavcalc: float = 1.1620
-    constructloadfactorpermfav: float = 1.00
-    constructloadfactorvarfav: float = 0.00
-    constructloadfactorpermunfavmultiply: float = 1.35
-    constructloadfactorvarunfavmultiply: float = 1.50
-    constructloadfactorpermunfavcalc: float = 1.1205
-    constructloadfactorvarunfavcalc: float = 1.2450
-    effectfactor: float = 1.00
-    effectfactorvarunfav: float = 1.00
-    materialfactorcohesion: float = 1.30
-    materialfactorundrainedshearstrength: float = 1.50
-    materialfactortgphi: float = 1.300
-    materialfactorsubgradereaction: float = 1.00
-    resistancefactor: float = 1.00
-    geometryincretainingheight: float = 0.00
-    geometrymaxincretainingheight: float = 0.00
-    geometrydeltapassivesurfacelevel: float = 0.00
-    geometrydeltapassivephreaticline: float = 0.00
-    geometrydeltaactivephreaticline: float = 0.00
-    overallstabilityfactordrivingmoment: float = 1.00
-    overallstabilityfactorcohesion: float = 1.30
-    overallstabilityfactortgphi: float = 1.30
-    overallstabilityfactorunitweight: float = 1.00
-    factorrepvaluesmdpmax: float = 1.00
-    verticalbalancegammamb: float = 1.30
-
-
-class PartialFactorsEc7SeVk2(DSeriesInlineMappedProperties):
-    safetyfactorgammad: float = 0.91
-    safetyfactoreta: float = 1.00
-    loadfactorpermunfav: float = 1.00
-    loadfactorpermfav: float = 1.00
-    loadfactorvarunfav: float = 1.00
-    loadfactorvarfav: float = 0.00
-    loadfactorpermunfavmultiply: float = 1.10
-    loadfactorvarunfavmultiply: float = 1.40
-    loadfactorpermunfavcalc: float = 1.0010
-    loadfactorvarunfavcalc: float = 1.2740
-    constructloadfactorpermfav: float = 1.00
-    constructloadfactorvarfav: float = 0.00
-    constructloadfactorpermunfavmultiply: float = 1.35
-    constructloadfactorvarunfavmultiply: float = 1.50
-    constructloadfactorpermunfavcalc: float = 1.2285
-    constructloadfactorvarunfavcalc: float = 1.3650
-    effectfactor: float = 1.00
-    effectfactorvarunfav: float = 1.00
-    materialfactorcohesion: float = 1.30
-    materialfactorundrainedshearstrength: float = 1.50
-    materialfactortgphi: float = 1.300
-    materialfactorsubgradereaction: float = 1.00
-    resistancefactor: float = 1.00
-    geometryincretainingheight: float = 0.00
-    geometrymaxincretainingheight: float = 0.00
-    geometrydeltapassivesurfacelevel: float = 0.00
-    geometrydeltapassivephreaticline: float = 0.00
-    geometrydeltaactivephreaticline: float = 0.00
-    overallstabilityfactordrivingmoment: float = 1.00
-    overallstabilityfactorcohesion: float = 1.30
-    overallstabilityfactortgphi: float = 1.30
-    overallstabilityfactorunitweight: float = 1.00
-    factorrepvaluesmdpmax: float = 1.00
-    verticalbalancegammamb: float = 1.30
-
-
-class PartialFactorsEc7SeVk3(DSeriesInlineMappedProperties):
-    safetyfactorgammad: float = 1.00
-    safetyfactoreta: float = 1.00
-    loadfactorpermunfav: float = 1.00
-    loadfactorpermfav: float = 1.00
-    loadfactorvarunfav: float = 1.00
-    loadfactorvarfav: float = 0.00
-    loadfactorpermunfavmultiply: float = 1.10
-    loadfactorvarunfavmultiply: float = 1.40
-    loadfactorpermunfavcalc: float = 1.1000
-    loadfactorvarunfavcalc: float = 1.4000
-    constructloadfactorpermfav: float = 1.00
-    constructloadfactorvarfav: float = 0.00
-    constructloadfactorpermunfavmultiply: float = 1.35
-    constructloadfactorvarunfavmultiply: float = 1.50
-    constructloadfactorpermunfavcalc: float = 1.3500
-    constructloadfactorvarunfavcalc: float = 1.5000
-    effectfactor: float = 1.00
-    effectfactorvarunfav: float = 1.00
-    materialfactorcohesion: float = 1.30
-    materialfactorundrainedshearstrength: float = 1.50
-    materialfactortgphi: float = 1.300
-    materialfactorsubgradereaction: float = 1.00
-    resistancefactor: float = 1.00
-    geometryincretainingheight: float = 0.00
-    geometrymaxincretainingheight: float = 0.00
-    geometrydeltapassivesurfacelevel: float = 0.00
-    geometrydeltapassivephreaticline: float = 0.00
-    geometrydeltaactivephreaticline: float = 0.00
-    overallstabilityfactordrivingmoment: float = 1.00
-    overallstabilityfactorcohesion: float = 1.30
-    overallstabilityfactortgphi: float = 1.30
-    overallstabilityfactorunitweight: float = 1.00
-    factorrepvaluesmdpmax: float = 1.00
-    verticalbalancegammamb: float = 1.30
