@@ -1,6 +1,7 @@
 from enum import Enum, IntEnum
 
-from pydantic import conint
+from pydantic import Field
+from typing_extensions import Annotated
 
 from geolib.models import BaseDataClass
 
@@ -33,12 +34,12 @@ class LateralEarthPressureMethodStage(IntEnum):
 class ModelType(IntEnum):
     """Represents the model types from D-Sheet Piling using the same integer values used in the application.
 
-    The Model type determines the kind of calculation that's performed on the construction.
+    The Model type determines the kind of construction: single pile or sheet piling.
+    Note that the model type SHEET_PILING includes sheet piling, wooden sheet piling and diaphragm wall.
     """
 
     SHEET_PILING = 0
     SINGLE_PILE = 1
-    DIAPHRAGM_WALL = 2
 
 
 class SinglePileLoadOptions(Enum):
@@ -119,11 +120,29 @@ class PartialFactorSetEC7NADNL(IntEnum):
     RC1 = 1
     RC2 = 2
     RC3 = 3
+    SLS = 4
 
 
-class PartialFactorSetEC7NADB(IntEnum):
-    SET1 = 0
-    SET2 = 1
+class AssessmentTypeEC7NL(IntEnum):
+    NewConstruction = 0
+    Reconstruction = 1
+    ReconstructionAccordingToBouwBesluit2003OrBefore = 2
+    Disapproval = 3
+
+
+class PartialFactorSetEC7NADBE(IntEnum):
+    RC1SET1 = 0
+    RC1SET2 = 1
+    RC2SET1 = 2
+    RC2SET2 = 3
+    RC3SET1 = 4
+    RC3SET2 = 5
+
+
+class RiskClassEC7BE(IntEnum):
+    RC1 = 0
+    RC2 = 1
+    RC3 = 2
 
 
 class PartialFactorSetCUR(IntEnum):
@@ -131,6 +150,7 @@ class PartialFactorSetCUR(IntEnum):
     CLASSI = 0
     CLASSII = 1
     CLASSIII = 2
+    SLS = 3
 
 
 class PartialFactorCalculationType(IntEnum):
@@ -155,7 +175,7 @@ class PartialFactorSetVerifyEC(IntEnum):
 class SoilTypeModulusSubgradeReaction(IntEnum):
     GRAVEL = 0
     SAND = 1
-    LOAM = 2
+    SILT = 2
     CLAY = 3
     PEAT = 4
 
@@ -204,7 +224,7 @@ class ModulusReactionType(Enum):
 class CurveSettings(BaseDataClass):
     modulus_reaction_type: ModulusReactionType = ModulusReactionType.SECANT
     use_unloading_reloading_curve: bool = False
-    curve_number: conint(ge=1, le=4) = 3
+    curve_number: Annotated[int, Field(ge=1, le=4)] = 3
 
 
 class LoadTypeFavourableUnfavourable(IntEnum):
