@@ -1,3 +1,7 @@
+"""
+Module containing the common soil object definition.
+"""
+
 from .soil import (
     BjerrumParameters,
     ConeResistance,
@@ -13,6 +17,8 @@ from .soil import (
     ModulusSubgradeReaction,
     MohrCoulombParameters,
     ShearStrengthModelTypePhreaticLevel,
+    SigmaTauParameters,
+    SigmaTauTablePoint,
     Soil,
     SoilClassificationParameters,
     SoilState,
